<?php

namespace App\Exports;

use App\Models\CashExpense;
use App\Models\CashPurchase;
use App\Models\Deposit;
use App\Models\drivewayAccount;
use App\Models\DrivewaySheet;
use App\Models\GeneralLedger;
use App\Models\Header;
use App\Models\Machine;
use App\Models\Sale;
use App\Models\SheelCard;
use App\Models\SpeedPoint;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromView;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;

class DailyReportExport implements FromView,ShouldAutoSize
{
    public function view(): View
    {
        $header_query = Header::query()->with('subcategories')->get();
        // Fuel Sales
        $fuel_sale_header = $header_query->where('category_type','sale')->where('code','cat26')->first();
        $fuel_sale_sub = null;
        if (!empty($fuel_sale_header)) {
            $fuel_sale_sub = $fuel_sale_header->subcategories;
        }

        $sale = Sale::query()->where('branch_id',session()->get('branch_id'))->get();

        // Fs Cash Deposit
        $fs_cash_deposit_category = $header_query->where('code','cat22')->first();
        $fs_cash_deposit_sub_category = null;
        if (!empty($fs_cash_deposit_category)) {
            $fs_cash_deposit_sub_category = $fs_cash_deposit_category->subcategories;
        }
        // FNB Cheque Deposit
        $cheque_category = $header_query->where('code','cat24')->first();
        $cheque_sub_category = null;
        if (!empty($cheque_category)) {
            $cheque_sub_category = $cheque_category->subcategories;
        }
        // NON FNB Cheque Deposit
        $non_cheque_category = $header_query->where('code','cat25')->first();
        $non_cheque_sub_category = null;
        if (!empty($non_cheque_category)) {
            $non_cheque_sub_category = $non_cheque_category->subcategories;
        }
        // For EFT
        $eft_category = $header_query->where('code','cat23')->first();
        $eft_sub_category = null;
        if (!empty($eft_category)) {
            $eft_sub_category = $eft_category->subcategories;
        }
        // For PD cheque payment/deposit
        $pd_pay_category = $header_query->where('code','cat37')->first();
        $pd_pay_sub_category = null;
        if (!empty($pd_pay_category)) {
            $pd_pay_sub_category = $pd_pay_category->subcategories;
        }
        // For PD cheque
        $pd_chq_category = $header_query->where('code','cat36')->first();
        $pd_chq_sub_category = null;
        if (!empty($pd_chq_category)) {
            $pd_chq_sub_category = $pd_chq_category->subcategories;
        }
        // For Speed Point
        $machine = Machine::query()->get()->pluck('type','id')->unique();
        $speed_point = SpeedPoint::where('branch_id',session()->get('branch_id'))
                        ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                        ->select('m.type','reconcilation_type','date','amount')->get();
        // Account
        $driveway_account = drivewayAccount::query()->where('branch_id',session()->get('branch_id'))->with('account_info')->get();
        // For RANDS
        $rand_category = $header_query->where('code','cat34')->first();
        $rand_sub_category = null;
        if (!empty($rand_category)) {
            $rand_sub_category = $rand_category->subcategories;
        }
        // Deposit
        $query = DrivewaySheet::query()->where('branch_id',session()->get('branch_id'));
        $deposit_fs = Deposit::query()->where('branch_id',session()->get('branch_id'))->with('financialCategory','bank_statement')->get();
        // Fs Expense
        $exp_header = $header_query->where('category_type','expense');
        $fs_exp = $exp_header->where('code','cat32')->first();
        $fs_exp_sub_cat = null;
        if (!empty($fs_exp)) {
            $fs_exp_sub_cat = $fs_exp->subcategories;
        }
        $expense = CashExpense::query()->where('branch_id',session()->get('branch_id'))->with('financialCategory')->get();
        // For Shell Card
        $shell_card = SheelCard::query()->where('branch_id',session()->get('branch_id'))->get();
        // General Ledger
        $other_sub = $header_query->where('category_type','other');
        $general_ledger = GeneralLedger::query()->where('branch_id',session()->get('branch_id'))->get();
        // Fs Purchase
        $fs_pur = $header_query->where('category_type','purchase')->where('code','cat33')->first();
        $fs_pur_sub_cat = null;
        if (!empty($fs_pur)) {
            $fs_pur_sub_cat = $fs_pur->subcategories;
        }
        $purchase = CashPurchase::query()->where('branch_id',session()->get('branch_id'))->with('financialCategory')->get();

        $drivewaysheet = $query->get();
        $date = $drivewaysheet->pluck('date')->unique();

        return view('exports.dailyReport',compact(
            'date','fs_cash_deposit_sub_category','cheque_sub_category',
            'non_cheque_sub_category','eft_sub_category','rand_sub_category','drivewaysheet',
            'deposit_fs','fs_exp_sub_cat','expense','fs_pur_sub_cat','purchase',
            'driveway_account','fuel_sale_sub','sale','machine','pd_pay_sub_category','pd_chq_sub_category',
            'speed_point','shell_card','other_sub','general_ledger'
        ));
    }
}
