<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Cashier;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Gate;

class CashierController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('cashier_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashier_list = Cashier::where('branch_id',$this->branch_id)->get();
        return view('admin.deposit.cashier',compact('cashier_list'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('cashier_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

       $request->validate([
            'name' => 'required|string|max:40|unique:cashiers',
            'surname' => 'nullable',
            'type' => 'required',
            'status' => 'nullable',
        ]);
        $input = $request->all();
        $input['status'] = isset($input['status']) ? '1' : '0';
        $input['branch_id'] = $this->branch_id;
        // return $input;
        Cashier::create($input);
        toastr()->success('Cashier is created successfully!');
        return redirect()->route('admin.cashier.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Cashier  $cashier
     * @return \Illuminate\Http\Response
     */
    public function show(Cashier $cashier)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Cashier  $cashier
     * @return \Illuminate\Http\Response
     */
    public function edit(Cashier $cashier)
    {
        abort_if(Gate::denies('cashier_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashier_list = Cashier::where('branch_id',$this->branch_id)->get();
        return view('admin.deposit.cashier',compact('cashier_list','cashier'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Cashier  $cashier
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Cashier $cashier)
    {
        abort_if(Gate::denies('cashier_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'name' => 'required|string|max:40|unique:cashiers,id,'.$cashier->id,
            'surname' => 'nullable',
            'type' => 'required',
            'status' => 'nullable',
        ]);
        $input = $request->all();
        $input['status'] = isset($input['status']) ? '1' : '0';
        $input['branch_id'] = $this->branch_id;
        $cashier->update($input);
        toastr()->info('Cashier is updated successfully!');
        return redirect()->route('admin.cashier.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Cashier  $cashier
     * @return \Illuminate\Http\Response
     */
    public function destroy(Cashier $cashier)
    {
        abort_if(Gate::denies('cashier_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if((isset($cashier->deposits) && count($cashier->deposits) > 0)){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $cashier->delete();
        toastr()->error('Cashier has been deleted!');
        return back();
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('cashier_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:cashiers,id',
        ]);

        foreach($request->ids as $id){
            $cashier = Cashier::find($id);
            $this->destroy($cashier);
        }
        // toastr()->error('Cashier has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
