<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Setting;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class ConfigController extends Controller
{

    // To show mail settings.
    public function mail()
    {
        abort_if(Gate::denies('mail_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.mail');
    }

    // To update mail settings.
    public function mail_update(Request $request)
    {
        abort_if(Gate::denies('mail_setting_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $input      = $request->all();
        $env_update = $this->changeEnv([
            'MAIL_FROM_NAME'    => $request->MAIL_FROM_NAME,
            'MAIL_DRIVER'       => $request->MAIL_DRIVER,
            'MAIL_HOST'         => $request->MAIL_HOST,
            'MAIL_PORT'         => $request->MAIL_PORT,
            'MAIL_USERNAME'     => $request->MAIL_USERNAME,
            'MAIL_FROM_ADDRESS' => $string = preg_replace('/\s+/', '', $request->MAIL_USERNAME),
            'MAIL_PASSWORD'     => $request->MAIL_PASSWORD,
            'MAIL_ENCRYPTION'   => $request->MAIL_ENCRYPTION,
        ]);

        if ($env_update) {
            toastr()->success('Mail Settings has been updated');
            return back()->with('updated', 'Mail settings has been updated');
        } else {
            toastr()->error('Mail settings could not be saved');
            return back()->with('deleted', 'Mail settings could not be saved');
        }
    }

  // To show social login settings page.
    public function sociallogin()
    {
        abort_if(Gate::denies('social_login_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.settings.socialLogin');
    }

    // To update social login settings.
    public function sociallogin_update(Request $request)
    {
        abort_if(Gate::denies('social_login_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $input = $request->all();
        if (!isset($input['is_google'])) {
            $input['is_google'] = 0;
        } else {
            $request->validate([
                'GOOGLE_CLIENT_ID'     => 'required',
                'GOOGLE_CLIENT_SECRET' => 'required',
                'GOOGLE_CALLBACK_URL'  => 'required',
            ]);
        }
        if (!isset($input['is_fb'])) {
            $input['is_fb'] = 0;
        } else {
            $request->validate([
                'FACEBOOK_CLIENT_ID'     => 'required',
                'FACEBOOK_CLIENT_SECRET' => 'required',
                'FB_CALLBACK_URL'        => 'required',
            ]);
        }
        if (!isset($input['is_gitlab'])) {
            $input['is_gitlab'] = 0;
        } else {
            $request->validate([
                'GITLAB_CLIENT_ID'     => 'required',
                'GITLAB_CLIENT_SECRET' => 'required',
                'GITLAB_CALLBACK_URL'  => 'required',
            ]);
        }
        // change values in .env
        $env_update = $this->changeEnv([
            'GOOGLE_CLIENT_ID'       => $request->GOOGLE_CLIENT_ID,
            'GOOGLE_CLIENT_SECRET'   => $request->GOOGLE_CLIENT_SECRET,
            'GOOGLE_CALLBACK_URL'    => $request->GOOGLE_CALLBACK_URL,
            'FACEBOOK_CLIENT_ID'     => $request->FACEBOOK_CLIENT_ID,
            'FACEBOOK_CLIENT_SECRET' => $request->FACEBOOK_CLIENT_SECRET,
            'FB_CALLBACK_URL'        => $request->FB_CALLBACK_URL,
            'GITLAB_CLIENT_ID'       => $request->GITLAB_CLIENT_ID,
            'GITLAB_CLIENT_SECRET'   => $request->GITLAB_CLIENT_SECRET,
            'GITLAB_CALLBACK_URL'    => $request->GITLAB_CALLBACK_URL,
        ]);
        $sdata   = ['is_google' => $input['is_google'], 'is_fb' => $input['is_fb'], 'is_gitlab' => $input['is_gitlab']];
        $setting = Setting::all();
        foreach ($sdata as $key => $val) {
            $data = $setting->where('name', $key)->first();
            if ($data) {
                $data->update(['val' => $val]);
            } else {
                Setting::create(['name' => $key, 'val' => $val]);
            }
        }
        \Cache::forget('settings');
        if ($env_update) {
            toastr()->success('API Settings has been updated');
            return back()->with('updated', 'API settings has been updated');
        } else {
            toastr()->error('API settings could not be saved');
            return back()->with('deleted', 'API settings could not be saved');
        }
    }

}
