<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Artisan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use ZipArchive;

class DbBackupController extends Controller
{
    public function updatepath(Request $request)
    {
        $env_update = $this->changeEnv(['MYSQL_PATH' => $request->MYSQL_PATH]);
        toastr()->success('MYSQL dump path added successfully');
        return back()->with('added', 'MYSQL dump path Successfully added !');
    }

    public function index()
    {
        $backups = [];
        $files   = Storage::files('backup');
        foreach ($files as $file) {
            $size         = Storage::size($file);
            $name         = explode('/', $file)[1];
            $lastmodified = Storage::lastModified($file);
            $lastmodified = date("Y-m-d H:i:s", $lastmodified);

            array_push($backups, [
                'name'          => $name,
                'last_modified' => $lastmodified,
                'size'          => $this->filesize($size),
            ]);
        }
        return view('admin.settings.backupRestore', compact('backups'));
    }
    private function filesize($bytes)
    {
        $units = ['B', 'KB', 'MB', 'GB', 'TB', 'PB'];
        for ($i = 0; $bytes > 1024; $i++) {
            $bytes /= 1024;
        }
        return round($bytes, 2) . ' ' . $units[$i];
    }

    public function store()
    {
        Artisan::call('database:backup');
        $output = Artisan::output();
        if ($output == '') {
            toastr()->success('Backup has been created successfully');
        } else {
            toastr()->error('Error in creating backup')->error();
        }
        return redirect('admin/backup');
    }
    public function upload(Request $request)
    {
        if (env('DEMO_LOCK') == 1) {
            flash('This action is disabled in demo !')->error();
            return back();
        }
        $request->validate([
            "file" => "required|mimes:sql,zip",
        ]);
        $input = $request->all();
        if ($file = $request->file('file')) {
            if ($file->getClientOriginalExtension() == 'zip') {
                $zip = new ZipArchive;
                if ($zip->open($file) === true && $zip->numFiles == 1) {
                    $filename = $zip->getNameIndex(0);
                    $fileinfo = pathinfo($filename);
                    if ($fileinfo['extension'] == 'sql') {
                        $flag = 0;
                    } else {
                        flash('Only sql file is allowed')->error();
                        return redirect('admin/backup');
                    }
                } else {
                    flash('Not a valid file')->error();
                    return redirect('admin/backup');
                }
                $zip->close();
            }
            $path = 'backup';
            $name = "backup-" . now()->format('Y-m-d-H-i-s') . ".sql";
            if (!file_exists(storage_path($path))) {
                mkdir(storage_path($path), 666, true);
            }

            $file->storeAs($path, $name);
        }
        toastr()->success('File uploaded successfully');
        return redirect('admin/backup');
    }
    public function restore($file)
    {
        if (env('DEMO_LOCK') == 1) {
            flash('This action is disabled in demo !')->error();
            return back();
        }
        $path      = storage_path() . "\\app\\backup\\";
        $sqlpath   = config('database.connections.mysql.dump.setDumpBinaryPath') . "\\";
        $command   = $sqlpath . "mysql --user=" . env('DB_USERNAME') . " --password=" . env('DB_PASSWORD') . " --host=" . env('DB_HOST') . " " . env('DB_DATABASE') . "  < " . $path . $file . "  2>&1";
        $returnVar = null;
        $output    = null;
        exec($command, $output, $returnVar);
        if (!$returnVar) {
            toastr()->success('Backup Restored successfully');
        } else {
            toastr()->error('Error in Backup Restoration');
        }
        return back();
    }
    public function destroy($file)
    {
        if (env('DEMO_LOCK') == 1) {
            flash('This action is disabled in demo !')->error();
            return back();
        }
        $file_path = realpath(storage_path('app/backup/' . $file));
        if (file_exists($file_path)) {
            Storage::disk('local')->delete('backup/' . $file);
        }
        toastr()->error('Backup has been deleted');
        return back();
    }
    public function download($file)
    {
        if (env('DEMO_LOCK') == 1) {
            toastr()->error('This action is disabled in demo !');
            return back();
        }
        $file_path = realpath(storage_path('app/backup/' . $file));
        if (file_exists($file_path)) {
            return \Response::download($file_path, $file);
        } else {
            toastr()->error('Requested file does not exist on our server!');
            return back()->with('error', 'Requested file does not exist on our server!');
        }
    }

    protected function changeEnv($data = array())
    {
        if (count($data) > 0) {
            // Read .env-file
            $env = file_get_contents(base_path() . '/.env');
            // Split string on every " " and write into array
            $env = preg_split('/\s+/', $env);
            // Loop through given data
            foreach ((array) $data as $key => $value) {
                // Loop through .env-data
                foreach ($env as $env_key => $env_value) {
                    // Turn the value into an array and stop after the first split
                    // So it's not possible to split e.g. the App-Key by accident
                    $entry = explode("=", $env_value, 2);
                    // Check, if new key fits the actual .env-key
                    if ($entry[0] == $key) {
                        // If yes, overwrite it with the new one
                        $env[$env_key] = $key . "=" . $value;
                    } else {
                        // If not, keep the old one
                        $env[$env_key] = $env_value;
                    }
                }
            }

            // Turn the array back to an String
            $env = implode("\n", $env);

            // And overwrite the .env with the new data
            file_put_contents(base_path() . '/.env', $env);

            return true;
        } else {
            return false;
        }
    }
}
