<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyDrivewaySheetRequest;
use App\Http\Requests\StoreDrivewaySheetRequest;
use App\Http\Requests\UpdateDrivewaySheetRequest;
use App\Models\DrivewaySheet;
use App\Models\Fuel;
use App\Models\Pump;
use Gate;
use App\Models\SiteRegister;
use App\Models\FuelStock;
use App\Models\FuelInfo;
use Illuminate\Http\Request;
use Session;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class DrivewaySheetController extends Controller
{
    use CsvImportTrait;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }

    // Index drivewaysheet
    public function index(Request $request)
    {
        abort_if(Gate::denies('driveway_sheet_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $drivewaysheet = DrivewaySheet::where('branch_id',$this->branch_id)->select('date as date1','is_approved')->groupBy('date')->get();
        return view('admin.drivewaySheets.index',compact('drivewaysheet'));

    }

    // Create drivewaysheet
    public function create(Request $request)
    {
        abort_if(Gate::denies('driveway_sheet_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $reqdate =  $request->date;
        $drivedata = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$reqdate)->get();
        if (count($drivedata) > 0) {
        //   return redirect()->route('admin.driveway-sheets.view', $date);
           return redirect()->route('admin.driveway-sheets.view', $reqdate);
        }
        $last = DrivewaySheet::where('branch_id',$this->branch_id)->select('date as date1')->orderBy('date','desc')->first();
        $lastdate = !empty($last) ? $last->date1 : null;
        $site = SiteRegister::with('pumps')->where('id',$this->branch_id)->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->where('is_fake',0)->unique();
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        $date = $lastdate != null ? date('Y-m-d', strtotime('+1 day', strtotime($lastdate))) : ($reqdate != null ? $reqdate : null);
        $drivesheet = collect();
        $fuelsheet = collect();
        if(date('d') != '01' &&  $lastdate != null){
            $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$lastdate)->get();
            $fuelsheet = FuelStock::where('branch_id',$this->branch_id)->whereDate('date',$lastdate)->get();
        }
        return view('admin.drivewaySheets.create',compact('pumps','fuels','site','drivesheet','date','fuelsheet'));
    }

    // Store drivewaysheet
    public function store(StoreDrivewaySheetRequest $request)
    {
        $date1 = strtr($request->date, '/', '-');
        $date = date('Y-m-d', strtotime($date1));

        //restrict if driveway sheet is created already
        // $exist = DrivewaySheet::whereDate('date',$date)->first();
        $exist = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$date)->first();
        if(!empty($exist)){
            if($request->ajax()){
                return response()->json(['success'=>false,'message'=>'Driveway sheet is already created for this date!']);
            }
            toastr()->error('Driveway sheet is already created for this date!');
            return back();
        }

        //store drivewaysheet
        $fuelprices = FuelInfo::where('branch_id',$this->branch_id)->where('status','1')->get();
        foreach($request->pump_id as $key => $data){
            $selling_price = $fuelprices->where('fuel_id',$request->fuel_id[$key])->first();
            $price = $selling_price ? $selling_price->selling_price : '0';
            $drivewaySheet = DrivewaySheet::create([
                'branch_id' => $this->branch_id,
                'date' => $request->date,
                'pump_id' => $request->pump_id[$key],
                'fuel_id' => $request->fuel_id[$key],
                'opening_balance' => $request->opening_balance[$key],
                'closing_balance' => $request->closing_balance[$key],
                'stock' => $request->stock[$key],
                'price' => $price,
                'stock_value' => $request->stock[$key] * (float)($price),
            ]);
        }

        //store fuelstock
        foreach($request->fuel_stock as $key => $value){
            $fuelstock = FuelStock::create([
                'branch_id' => $this->branch_id,
                'date' => $request->date,
                'fuel_type' => $request->fuel_stock[$key],
                'opening_stock' => $request->opening_stock[$key],
                'purchase' => $request->purchase[$key],
                'stock' => $request->calculated_stock[$key],
                'closing_dips' => $request->closing_dips[$key],
                'sale' => $request->computer_sale[$key],
            ]);
        }

        if($request->ajax()){
            return response()->json(['success'=>true,'message'=>'Driveway sheet has been created!']);
        }
        toastr()->success('Driveway sheet is created successfully!');
        return redirect()->route('admin.driveway-sheets.index');
    }

    // Mass destory drivewaysheet
    public function massDestroy(MassDestroyDrivewaySheetRequest $request)
    {
        DrivewaySheet::whereIn('id', request('ids'))->delete();
        return response(null, Response::HTTP_NO_CONTENT);
    }

    // Show drivewaysheet
    public function drivesheet_view($date)
    {
        $site = SiteRegister::with('pumps')->where('id',$this->branch_id)->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->where('is_fake',0)->unique();
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        $fuelprices = FuelInfo::where('branch_id',$this->branch_id)->whereDate('effective_from','<=',$date)->whereNull('effective_to')->orWhereDate('effective_to','>',$date)->get();
        $fuelstock = FuelStock::where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        return view('admin.drivewaySheets.show',compact('pumps','fuels','drivesheet','date','fuelprices','fuelstock'));
    }

    // Edit drivewaysheet
    public function drivesheet_edit($date)
    {
        //restrict if driveway sheet is approved
        $first = DrivewaySheet::where('branch_id',$this->branch_id)->where('date',$date)->first();
        if(isset($first->is_approved) && $first->is_approved == 1){
            return redirect()->route('admin.driveway-sheets.index');
        }

        $site = SiteRegister::with('pumps')->where('id',$this->branch_id)->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->where('is_fake',0)->unique();
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)->where('date',$date)->get();
        $fuelstock = FuelStock::where('branch_id',$this->branch_id)->where('date',$date)->get();
        return view('admin.drivewaySheets.edit',compact('pumps','fuels','drivesheet','date','fuelstock'));
    }

    // Update drivewaysheet
    public function drivesheet_update(UpdateDrivewaySheetRequest $request)
    {
        $date1 = strtr($request->date, '/', '-');
        $date = date('Y-m-d', strtotime($date1));

        //restrict if driveway sheet is approved
        $first = DrivewaySheet::where('branch_id',$this->branch_id)->where('date',$date)->first();
        if(isset($first->is_approved) && $first->is_approved == 1){
            toastr()->error('Driveway sheet can\'t be deleted!');
            return redirect()->route('admin.driveway-sheets.index');
        }

        //restrict if driveway sheet is created already
        $exist = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$date)->whereNotIn('id',$request->id)->first();
        if(!empty($exist)){
            if($request->ajax()){
                return response()->json(['success'=>false,'message'=>'Driveway sheet is already created for this date!']);
            }
            toastr()->error('Driveway sheet is already created for this date!');
            return back();
        }

        //update drivewaysheet
        $fuelprices = FuelInfo::where('branch_id',$this->branch_id)->where('status','1')->get();
        foreach($request->id as $key => $data){
            $driveway = DrivewaySheet::find($data);
            $selling_price = $fuelprices->where('fuel_id',$request->fuel_id[$key])->first();
            $price = $selling_price ? $selling_price->selling_price : '0';
            if(!empty($driveway)){
                $drivewaySheet = $driveway->update([
                    'branch_id' => $this->branch_id,
                    'date' => $request->date,
                    'pump_id' => $request->pump_id[$key],
                    'fuel_id' => $request->fuel_id[$key],
                    'opening_balance' => $request->opening_balance[$key],
                    'closing_balance' => $request->closing_balance[$key],
                    'stock' => $request->stock[$key],
                    'price' => $price,
                    'stock_value' => $request->stock[$key] * (float)($price),
                ]);
            }
        }

        //update feulstock
        foreach($request->fuel_stock as $key => $value){
            $fuelstock = FuelStock::find($request->fuel_stock_id[$key]);
            if(!empty($fuelstock)){
                $fuelstock->update([
                    'branch_id' => $this->branch_id,
                    'date' => $request->date,
                    'fuel_type' => $request->fuel_stock[$key],
                    'opening_stock' => $request->opening_stock[$key],
                    'purchase' => $request->purchase[$key],
                    'stock' => $request->calculated_stock[$key],
                    'closing_dips' => $request->closing_dips[$key],
                    'sale' => $request->computer_sale[$key],
                ]);
            }
            else{
                $fuelstock = FuelStock::create([
                    'branch_id' => $this->branch_id,
                    'date' => $request->date,
                    'fuel_type' => $request->fuel_stock[$key],
                    'opening_stock' => $request->opening_stock[$key],
                    'purchase' => $request->purchase[$key],
                    'stock' => $request->calculated_stock[$key],
                    'closing_dips' => $request->closing_dips[$key],
                    'sale' => $request->computer_sale[$key],
                ]);
            }
        }
        if($request->ajax()){
            return response()->json(['success'=>true,'message'=>'Driveway sheet is updated!']);
        }
        toastr()->info('Driveway sheet has been updated successfully!');
        return redirect()->route('admin.driveway-sheets.index');
    }

    // Update Drivesheet opening balance
    public function drivesheet_balance(Request $request)
    {
        //restrict if driveway sheet is approved
        $drivewaysheet = DrivewaySheet::where('branch_id',$this->branch_id)->where('id',$request->id)->first();
        if(isset($drivewaysheet->is_approved) && $drivewaysheet->is_approved == 1){
            toastr()->error('Driveway sheet can\'t be deleted!');
            return redirect()->route('admin.driveway-sheets.index');
        }

        //update drivewaysheet
        $drivewaysheet->update([
            'opening_balance' => $request->opening_balance,
            'closing_balance' => $request->closing_balance,
            'stock' => $request->stock,
            'stock_value' => $request->stock * $drivewaysheet->price,
        ]);
        toastr()->info('Opening balance has been updated successfully!');
        return back();
    }

    // Delete drivewaysheet
    public function drivesheet_delete($date)
    {
        //restrict if driveway sheet is approved
        $first = DrivewaySheet::where('branch_id',$this->branch_id)->where('date',$date)->first();
        if(isset($first->is_approved) && $first->is_approved == 1){
            toastr()->error('Driveway sheet can\'t be deleted!');
            return redirect()->route('admin.driveway-sheets.index');
        }

        $ids = DrivewaySheet::where('branch_id',$this->branch_id)->where('date',$date)->pluck('id');
        DrivewaySheet::whereIn('id', $ids)->forceDelete();

        $fuelids = FuelStock::where('branch_id',$this->branch_id)->where('date',$date)->pluck('id');
        FuelStock::whereIn('id', $fuelids)->forceDelete();
        toastr()->error('Driveway sheet has been deleted!');
        return redirect()->route('admin.driveway-sheets.index');
    }

    // Approve drivewaysheet
    public function drivesheet_approve($date)
    {
        $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)
                                ->whereDate('date',$date)->update(['is_approved' => '1']);
        if(request()->ajax()){
            return response()->json('1',200);
        }
        toastr()->success('Driveway sheet is approved!');
        return back();
    }
}
