<?php

namespace App\Http\Controllers\Admin;

use App\Exports\BankingFsExport;
use App\Exports\BankingShopExport;
use App\Exports\DailyReportExport;
use App\Exports\DirectShopExport;
use App\Exports\DrivewayExport;
use App\Exports\WetStockExport;
use App\Exports\WetStockFuelExport;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Models\DrivewaySheet;
use App\Models\Pump;
use App\Models\CashExpense;
use App\Models\CreditPurchase;
use App\Models\CashPurchase;
use App\Models\PaymentAdvice;
use App\Models\Suplier;
use App\Models\Machine;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use App\Http\Controllers\Admin\Auth;
use App\Models\BankStatement;
use App\Models\CreditExpense;
use App\Models\FuelInfo;
use App\Models\SiteRegister;
use App\Models\DepositOrSale;
use App\Models\drivewayAccount;
use App\Models\FinancialCategory;
use App\Models\Fuel;
use App\Models\FuelStock;
use App\Models\Header;
use App\Models\SheelCard;
use App\Models\Sale;
use App\Models\CashierSale;
use App\Models\Deposit;
use App\Models\GeneralLedger;
use App\Models\SpeedPoint;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use Rap2hpoutre\FastExcel\FastExcel;
use Yajra\DataTables\Contracts\DataTable;
use Excel;

class ReportController extends Controller
{
    use CsvImportTrait;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }

    // DrivewaySheet
    public function driveway(Request $request)
    {
        abort_if(Gate::denies('driveway_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date = date('Y-m-d');
        $site = SiteRegister::with('pumps')->where('id',$this->branch_id)->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->where('is_fake',0)->unique();
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        if ($request->input('date') != null) {
            $date1 = strtr($request->date, '/', '-');
            $date = date('Y-m-d', strtotime($date1));
        }
        $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$date)->get();

        $fuelprices = FuelInfo::where('branch_id',$this->branch_id)->whereDate('effective_from','<=',$date)->whereNull('effective_to')->orWhereDate('effective_to','>',$date)->get();
        $fuelstock = FuelStock::where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        $shopsale = Sale::query()->with('financialCategory.header')->where('branch_id',$this->branch_id)
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat3');})->get();
        $fuelsale = Sale::query()->with('financialCategory.header')->where('branch_id',$this->branch_id)
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat26');})->get();
        $shell = SheelCard::where('branch_id',$this->branch_id)->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $driveway_account = drivewayAccount::where('branch_id',$this->branch_id)->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $speed = SpeedPoint::where('branch_id',$this->branch_id)->whereDate('date',$date)
                                ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                                ->select('m.type','reconcilation_type','date',\DB::raw("SUM(amount) as total_amount"))->groupBy('m.type')->get();
        $cashiersale = CashierSale::with('financialcategory')->where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        $category = Header::where('category_type','deposit')->get();
        $deposit = Deposit::with('financialCategory')
                            ->whereHas('financialCategory', function($query) {
                                $query->where('status','1');})
                            ->where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        return view('admin.reports.driveway',compact('drivesheet','fuelprices','pumps','fuels','date','fuelstock','shopsale','fuelsale','cashiersale','site','shell','driveway_account','speed','deposit','category'));
    }

    public function saleReport(Request $request)
    {
        abort_if(Gate::denies('sale_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $date = date('Y-m-d');
        $site = SiteRegister::with('pumps')->where('id',$this->branch_id)->first();
        $pumps = collect();
        $fuels = collect();
        if(!empty($site)){
            $pumps = $site->pumps->unique();
            $fuels = $site->fuels->unique()->pluck('fuel_name','id');
        }
        if ($request->input('date') != null) {
            $date1 = strtr($request->date, '/', '-');
            $date = date('Y-m-d', strtotime($date1));
        }
        $drivesheet = DrivewaySheet::where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        $shopsale = Sale::query()->with('financialCategory.header')->where('branch_id',$this->branch_id)
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat3');})->get();
        $fuelsale = Sale::query()->with('financialCategory.header')->where('branch_id',$this->branch_id)
                            ->whereDate('date',$date)
                            ->whereHas('financialCategory.header', function($query) {
                                $query->where('code','cat26');})->get();
        $shell = SheelCard::where('branch_id',$this->branch_id)->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $driveway_account = drivewayAccount::where('branch_id',$this->branch_id)->whereDate('date',$date)->select('date','amount',\DB::raw("SUM(amount) as total_amount"))->groupBy('date')->first();
        $speed = SpeedPoint::where('branch_id',$this->branch_id)->whereDate('date',$date)
                                ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                                ->select('m.type','reconcilation_type','date',\DB::raw("SUM(amount) as total_amount"))->groupBy('m.type')->get();
        $cashiersale = CashierSale::with('financialcategory')->where('branch_id',$this->branch_id)->whereDate('date',$date)->get();
        $deposit = Deposit::where('branch_id',$this->branch_id)->whereDate('date',$date)->sum('amount');
        return view('admin.reports.salereport',compact('drivesheet','shopsale','fuelsale','cashiersale','date','site','pumps','fuels','shell','driveway_account','speed','deposit'));
    }


    // Cash Expense

    public function cashExpense(Request $request)
    {
        abort_if(Gate::denies('cash_expense_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
            $totalAmount = CashExpense::sum('amount');

        }
        else
        {
            $fromDate = date("Y-d-m", strtotime($request->input('fromDate')));
            $toDate = date("Y-d-m", strtotime($request->input('toDate')));
            $totalAmount = CashExpense::wherebetween('date',[$fromDate,$toDate])->sum('amount');
        }
        if($request->ajax())
        {
            if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
                $query = CashExpense::with('suplier')->select('*')->get();

                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                return $table->make(true);
            }
            else{
                $query = CashExpense::with('suplier')->select('*')->wherebetween('date',[$fromDate,$toDate])->get();

                // return response()->json(['data' => $query,'total' => $totalAmount]);
                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                return $table->make(true);
            }


        }
        return view('admin.reports.cashExpense',compact('totalAmount'));
    }

    public function excelExportCashExpense()
    {
        return 'This is export Code';
    }


    // Credit Expense

    public function creditExpense(Request $request)
    {
        abort_if(Gate::denies('credit_expense_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
            $totalAmount = CreditExpense::sum('amount');

        }
        else
        {
            $fromDate = date("Y-d-m", strtotime($request->input('fromDate')));
            $toDate = date("Y-d-m", strtotime($request->input('toDate')));
            $totalAmount = CreditExpense::wherebetween('date',[$fromDate,$toDate])->sum('amount');
        }

        if($request->ajax())
        {
            if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
                $query = CreditExpense::with('suplier')->select('*')->get();

                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
            else{
                $query = CreditExpense::with('suplier')->select('*')->wherebetween('date',[$fromDate,$toDate])->get();

                // return response()->json(['data' => $query,'total' => $totalAmount]);
                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
        }

        return view('admin.reports.creditExpense',compact('totalAmount'));
    }

    public function excelExportCreditExpense()
    {
        return "This is export Code";
    }


    // Credit Purchase

    public function creditPurchase (Request $request)
    {
        abort_if(Gate::denies('credit_purchase_access_report'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
            $totalAmount = CreditPurchase::sum('amount');

        }
        else
        {
            $fromDate = date("Y-d-m", strtotime($request->input('fromDate')));
            $toDate = date("Y-d-m", strtotime($request->input('toDate')));
            $totalAmount = CreditPurchase::wherebetween('date',[$fromDate,$toDate])->sum('amount');
        }

        if($request->ajax())
        {
            if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
                $query = CreditPurchase::with('suplier')->select('*')->get();

                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
            else{
                $query = CreditPurchase::with('suplier')->select('*')->wherebetween('date',[$fromDate,$toDate])->get();

                // return response()->json(['data' => $query,'total' => $totalAmount]);
                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
        }

        return view('admin.reports.creditPurchase',compact('totalAmount'));
    }


    // Cash Purchase

    public function cashPurchase (Request $request)
    {
        abort_if(Gate::denies('cash_purchase_access_report'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
            $totalAmount = CashPurchase::sum('amount');

        }
        else
        {
            $fromDate = date("Y-d-m", strtotime($request->input('fromDate')));
            $toDate = date("Y-d-m", strtotime($request->input('toDate')));
            $totalAmount = CashPurchase::wherebetween('date',[$fromDate,$toDate])->sum('amount');
        }

        if($request->ajax())
        {
            if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
                $query = CashPurchase::with('suplier')->select('*')->get();

                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
            else{
                $query = CashPurchase::with('suplier')->select('*')->wherebetween('date',[$fromDate,$toDate])->get();

                // return response()->json(['data' => $query,'total' => $totalAmount]);
                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('invoice_no', function ($row) {
                    return $row->invoice_no ? $row->invoice_no : '';
                });

                $table->editColumn('suplier', function ($row) {
                    return $row->suplier ? $row->suplier->suplier : '';
                });

                $table->editColumn('amount', function ($row) {
                    return $row->amount ? $row->amount : '';
                });

                $table->addColumn('exclusive', function ($row) {
                    return $row->amount ? round($row->amount /1.12,2) : '';
                });

                $table->addColumn('vat', function ($row) {
                    return $row->amount ? round($row->amount - ($row->amount /1.12),2) : '';
                });

                return $table->make(true);
            }
        }

        return view('admin.reports.cashPurchase',compact('totalAmount'));
    }


    // Payment Advice

    public function paymentAdvice (Request $request)
    {
        abort_if(Gate::denies('cash_purchase_access_report'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
            $totalAmount = PaymentAdvice::sum('price');

        }
        else
        {
            $fromDate = date("Y-d-m", strtotime($request->input('fromDate')));
            $toDate = date("Y-d-m", strtotime($request->input('toDate')));
            $totalAmount = PaymentAdvice::wherebetween('date',[$fromDate,$toDate])->sum('price');
        }

        if($request->ajax())
        {
            if (($request->input('fromDate') == null) || ($request->input('toDate') == null)) {
                $query = PaymentAdvice::select('*')->get();

                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('shopSale', function ($row) {
                    return $row->shopSale ? $row->shopSale : '';
                });

                $table->editColumn('product', function ($row) {
                    return $row->product ? $row->product : '';
                });

                $table->editColumn('r_quantity', function ($row) {
                    return $row->r_quantity ? $row->r_quantity : '';
                });

                $table->editColumn('price', function ($row) {
                    return $row->price ? $row->price : '';
                });

                $table->addColumn('amount', function ($row) {
                    return $row->price ? round($row->price * $row->r_quantity,2) : '';
                });

                return $table->make(true);
            }
            else{
                $query = PaymentAdvice::select('*')->wherebetween('date',[$fromDate,$toDate])->get();

                // return response()->json(['data' => $query,'total' => $totalAmount]);
                $table = Datatables::of($query);


                $table->editColumn('date', function ($row) {
                    return $row->date ? $row->date : '';
                });

                $table->editColumn('shopSale', function ($row) {
                    return $row->shopSale ? $row->shopSale : '';
                });

                $table->editColumn('product', function ($row) {
                    return $row->product ? $row->product : '';
                });

                $table->editColumn('r_quantity', function ($row) {
                    return $row->r_quantity ? $row->r_quantity : '';
                });

                $table->editColumn('price', function ($row) {
                    return $row->price ? $row->price : '';
                });

                $table->addColumn('amount', function ($row) {
                    return $row->price ? round($row->price * $row->r_quantity,2) : '';
                });

                return $table->make(true);
            }
        }

        return view('admin.reports.paymentAdvice',compact('totalAmount'));
    }

    /**
     * wetStock for Display
     * wet stock Report
     *
     * @return void
     */
    public function wetStock(Request $request)
    {
        abort_if(Gate::denies('wet_stock_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $site = SiteRegister::where('id',$this->branch_id)->first();
        $fuels = collect();
        if (!empty($site)) {
            $fuels = $site->fuels->where('is_shell',0)->unique()->pluck('fuel_name','id');
        }
        $drivewaysheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->get();
        $query = FuelStock::query()->where('branch_id',$this->branch_id);

        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }

        $fuel_stock = $query->get();
        $date = $fuel_stock->pluck('date')->unique();
        return view('admin.reports.wetStock',compact('fuels','date','fuel_stock','drivewaysheet'));
    }

    /**
     * wetStockFuelType for
     * dispaly Fuel wise report
     *
     * @param  mixed $id
     * @return void
     */
    public function wetStockFuelType(Request $request,$id)
    {
        abort_if(Gate::denies('wet_stock_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $fuel_name = Fuel::find($id)->fuel_name;
        $drivewaysheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->where('fuel_id',$id)->get();
        $query = FuelStock::query()->where('branch_id',$this->branch_id);

        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }

        $fuel_stock = $query->where('fuel_type',$id)->get();
        $date = $fuel_stock->pluck('date')->unique();
        return view('admin.reports.wetStockFuelWise',compact('fuel_name','date','fuel_stock','drivewaysheet','id'));
    }

    // Direct Shop

    public function directShop(Request $request)
    {
        abort_if(Gate::denies('direct_shop_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $header_query = Header::query()->with('subcategories')->where('station','shop')->get();
        // For Shop Sale
        $shop_cat = $header_query->where('code','cat3')->first();
        $shop_sale_sub_cat = null;
        if (!empty($shop_cat)) {
            $shop_sale_sub_cat = $shop_cat->subcategories;
        }
        $sale = Sale::query()->where('branch_id',$this->branch_id)->get();
        // For Deposit
        $shop_deposit = $header_query->where('code','cat4')->first();
        $shop_deposit_sub_cat = null;
        if (!empty($shop_deposit)) {
            $shop_deposit_sub_cat = $shop_deposit->subcategories;
        }
        $query = DrivewaySheet::query()->where('branch_id',$this->branch_id);
        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }
        $drivesheet = $query->get();
        $deposit =  Deposit::query()->where('branch_id',$this->branch_id)->get();
        // For Expense
        $shop_exp = $header_query->where('code','cat1')->first();
        $shop_exp_sub_cat = null;
        if (!empty($shop_exp)) {
            $shop_exp_sub_cat = $shop_exp->subcategories;
        }
        $expense = CashExpense::query()->where('branch_id',$this->branch_id)->get();
        // For Purchase
        $cash_purchase = $header_query->where('code','cat2')->first();
        $shop_cash_purchase_sub_cat = null;
        if (!empty($cash_purchase)) {
            $shop_cash_purchase_sub_cat = $cash_purchase->subcategories;
        }
        $purchase = CashPurchase::query()->where('branch_id',$this->branch_id)->get();
        // For Refund
        $shop_refund = $header_query->where('code','cat29')->first();
        $shop_refund_sub_cat = null;
        if (!empty($shop_refund)) {
            $shop_refund_sub_cat = $shop_refund->subcategories;
        }
        // For Cashier shortage
        $shop_cashier_short = $header_query->where('code','cat20')->first();
        $shop_cashier_short_sub_cat = null;
        if (!empty($shop_cashier_short)) {
            $shop_cashier_short_sub_cat = $shop_cashier_short->subcategories;
        }
        // For Staff
        $shop_staff = $header_query->where('header_name','Shop Staff')->first();
        $shop_staff_sub_cat = null;
        if (!empty($shop_staff)) {
            $shop_staff_sub_cat = $shop_staff->subcategories;
        }
        $general_ledger = GeneralLedger::query()->where('branch_id',$this->branch_id)->get();
        $date = $drivesheet->pluck('date')->unique();
        return view('admin.reports.directShop',compact(
            'deposit','sale','purchase','expense','date',
            'shop_sale_sub_cat','shop_deposit_sub_cat',
            'shop_cash_purchase_sub_cat','shop_exp_sub_cat',
            'general_ledger','shop_refund_sub_cat','shop_cashier_short_sub_cat','shop_staff_sub_cat'
        ));
    }

    public function bankingFS(Request $request)
    {
        abort_if(Gate::denies('banking_fs_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $date = date('Y-m-d');
        $header_query = Header::query()->where('category_type','deposit')->get();
        // Fs Cash Deposit
        $category = $header_query->where('code','cat22')->first();
        $sub_category = null;
        if (!empty($category)) {
            $sub_category = $category->subcategories;
        }
        // FNB Cheque Deposit
        $cheque_category = $header_query->where('code','cat24')->first();
        $cheque_sub_category = null;
        if (!empty($cheque_category)) {
            $cheque_sub_category = $cheque_category->subcategories;
        }
        // NON FNB Cheque Deposit
        $non_cheque_category = $header_query->where('code','cat25')->first();
        $non_cheque_sub_category = null;
        if (!empty($cheque_category)) {
            $non_cheque_sub_category = $non_cheque_category->subcategories;
        }
        // For EFT
        $eft_category = $header_query->where('code','cat23')->first();
        $eft_sub_category = null;
        if (!empty($eft_category)) {
            $eft_sub_category = $eft_category->subcategories;
        }
        // For Speed Point
        $machine = Machine::query()->get()->pluck('type','id')->unique();
        $speed_point = SpeedPoint::where('branch_id',$this->branch_id)
                        ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                        ->select('m.type','reconcilation_type','date','amount')->get();
        // For RANDS
        $rand_category = $header_query->where('code','cat34')->first();
        $rand_sub_category = null;
        if (!empty($rand_category)) {
            $rand_sub_category = $rand_category->subcategories;
        }
        // Deposit
        $query = DrivewaySheet::query()->where('branch_id',$this->branch_id);
        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }
        $drivesheet = $query->get();
        $deposit_fs = Deposit::query()->where('branch_id',$this->branch_id)->get();
        $deposit_date = $drivesheet->pluck('date')->unique();
        return view('admin.reports.bankingFS',compact('date','deposit_fs','deposit_date','sub_category','eft_sub_category','machine','speed_point','cheque_sub_category','non_cheque_sub_category','rand_sub_category'));
    }


    public function bankingShop(Request $request)
    {
        abort_if(Gate::denies('banking_shop_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $date = date('Y-m-d');
        $category = Header::where('category_type','deposit')->where('code','cat4')->first();
        $sub_category = $category->subcategories;
        $query = DrivewaySheet::query()->where('branch_id',$this->branch_id);
        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }
        $drivesheet =$query->get();
        $deposit_shop = Deposit::query()->where('branch_id',$this->branch_id)->get();
        $deposit_date = $drivesheet->pluck('date')->unique();
        return view('admin.reports.bankingShop',compact('date','deposit_shop','sub_category','deposit_date'));
    }

    // Daily Report

    public function dailyReport(Request $request)
    {
        abort_if(Gate::denies('daily_report_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $header_query = Header::query()->with('subcategories')->get();
        // Fuel Sales
        $fuel_sale_header = $header_query->where('category_type','sale')->where('code','cat26')->first();
        $fuel_sale_sub = null;
        if (!empty($fuel_sale_header)) {
            $fuel_sale_sub = $fuel_sale_header->subcategories;
        }

        $sale = Sale::query()->where('branch_id',$this->branch_id)->get();

        // Fs Cash Deposit
        $fs_cash_deposit_category = $header_query->where('code','cat22')->first();
        $fs_cash_deposit_sub_category = null;
        if (!empty($fs_cash_deposit_category)) {
            $fs_cash_deposit_sub_category = $fs_cash_deposit_category->subcategories;
        }
        // FNB Cheque Deposit
        $cheque_category = $header_query->where('code','cat24')->first();
        $cheque_sub_category = null;
        if (!empty($cheque_category)) {
            $cheque_sub_category = $cheque_category->subcategories;
        }
        // NON FNB Cheque Deposit
        $non_cheque_category = $header_query->where('code','cat25')->first();
        $non_cheque_sub_category = null;
        if (!empty($non_cheque_category)) {
            $non_cheque_sub_category = $non_cheque_category->subcategories;
        }
        // For EFT
        $eft_category = $header_query->where('code','cat23')->first();
        $eft_sub_category = null;
        if (!empty($eft_category)) {
            $eft_sub_category = $eft_category->subcategories;
        }
        // For PD cheque payment/deposit
        $pd_pay_category = $header_query->where('code','cat37')->first();
        $pd_pay_sub_category = null;
        if (!empty($pd_pay_category)) {
            $pd_pay_sub_category = $pd_pay_category->subcategories;
        }
        // For PD cheque
        $pd_chq_category = $header_query->where('code','cat36')->first();
        $pd_chq_sub_category = null;
        if (!empty($pd_chq_category)) {
            $pd_chq_sub_category = $pd_chq_category->subcategories;
        }
        // For Speed Point
        $machine = Machine::query()->get()->pluck('type','id')->unique();
        $speed_point = SpeedPoint::where('branch_id',$this->branch_id)
                        ->leftjoin('machines as m', 'm.id', '=', 'speed_points.reconcilation_type')
                        ->select('m.type','reconcilation_type','date','amount')->get();
        // Account
        $driveway_account = drivewayAccount::query()->where('branch_id',$this->branch_id)->with('account_info')->get();
        // For RANDS
        $rand_category = $header_query->where('code','cat34')->first();
        $rand_sub_category = null;
        if (!empty($rand_category)) {
            $rand_sub_category = $rand_category->subcategories;
        }
        // Deposit
        $query = DrivewaySheet::query()->where('branch_id',$this->branch_id);
        $deposit_fs = Deposit::query()->where('branch_id',$this->branch_id)->with('financialCategory','bank_statement')->get();
        // Fs Expense
        $exp_header = $header_query->where('category_type','expense');
        $fs_exp = $exp_header->where('code','cat32')->first();
        $fs_exp_sub_cat = null;
        if (!empty($fs_exp)) {
            $fs_exp_sub_cat = $fs_exp->subcategories;
        }
        $expense = CashExpense::query()->where('branch_id',$this->branch_id)->with('financialCategory')->get();
        // For Shell Card
        $shell_card = SheelCard::query()->where('branch_id',$this->branch_id)->get();
        // General Ledger
        $other_sub = $header_query->where('category_type','other');
        $general_ledger = GeneralLedger::query()->where('branch_id',$this->branch_id)->get();
        // Fs Purchase
        $fs_pur = $header_query->where('category_type','purchase')->where('code','cat33')->first();
        $fs_pur_sub_cat = null;
        if (!empty($fs_pur)) {
            $fs_pur_sub_cat = $fs_pur->subcategories;
        }
        $purchase = CashPurchase::query()->where('branch_id',$this->branch_id)->with('financialCategory')->get();
        // Requested date
        if($request->from_date != null && $request->to_date != null)
        {
            $date_cus = strtr($request->from_date,'/','-');
            $date_from = date('Y-m-d',strtotime($date_cus));
            $date_cus_to = strtr($request->to_date,'/','-');
            $date_to = date('Y-m-d',strtotime($date_cus_to));
            $query = $query->whereDate('date','>=',$date_from)->whereDate('date','<=',$date_to);
        }
        $drivewaysheet = $query->get();
        $date = $drivewaysheet->pluck('date')->unique();

        return view('admin.reports.dailyReport',compact(
            'date','fs_cash_deposit_sub_category','cheque_sub_category',
            'non_cheque_sub_category','eft_sub_category','rand_sub_category','drivewaysheet',
            'deposit_fs','fs_exp_sub_cat','expense','fs_pur_sub_cat','purchase',
            'driveway_account','fuel_sale_sub','sale','machine','pd_pay_sub_category','pd_chq_sub_category',
            'speed_point','shell_card','other_sub','general_ledger'
        ));
    }

    //  Report Export
    public function exportBankingShop()
    {
        return Excel::download(new BankingShopExport, 'BankingShop.xlsx');
    }

    public function exportBankingFs()
    {
        return Excel::download(new BankingFsExport, 'BankingFs.xlsx');
    }

    public function exportDailyReport()
    {
        return Excel::download(new DailyReportExport, 'DailyReport.xlsx');
    }

    public function exportDirectShop()
    {
        return Excel::download(new DirectShopExport, 'DirectShop.xlsx');
    }

    public function exportWetStock()
    {
        return Excel::download(new WetStockExport, 'WetStock.xlsx');
    }

    public function exportWetStockFuel(Fuel $fuel)
    {
        return Excel::download(new WetStockFuelExport, 'WetStockFuel-'. $fuel->fuel_name .'.xlsx');
    }

    public function exportDriveway($date)
    {
        return Excel::download(new DrivewayExport, 'DrivewaySheet-'. $date .'.xlsx');
    }

}

