<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Social;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class SocialController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $all_social = Social::all();
        return view('admin.settings.socialIcon', compact('all_social'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $all_social = Social::all();
        return view('admin.settings.socialIcon', compact('all_social'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'title' => 'required',
            'icon'  => 'required',
            'url'   => 'required|url',
        ]);

        if (!isset($input['status'])) {
            $input['status'] = 0;
        }

        $input = $request->all();
        Social::create($input);
        \Cache::forget('socials');
        toastr()->success('Social has been added');
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Social $social)
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $all_social = Social::all();
        return view('admin.settings.socialIcon', compact('social', 'all_social'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Social $social)
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'title' => 'required',
            'icon'  => 'required',
            'url'   => 'required|url',
        ]);

        if (!isset($input['status'])) {
            $input['status'] = 0;
        }
        $input = $request->all();
        $social->update($input);
        \Cache::forget('socials');
        toastr()->success('Social has been updated');
        return redirect('admin/social');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Social $social)
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $social->delete();
        toastr()->error('Social has been deleted');
        return back();
    }

    // Social icons status update.
    public function status_update(Request $request, $id)
    {
        abort_if(Gate::denies('social_icon_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $social = Social::findOrFail($id);
        $input  = $request->all();
        if (!isset($input['status'])) {
            $input['status'] = 0;
        }
        \Cache::forget('socials');
        $social->update($input);
        toastr()->success('Social status has been changed');
        return back()->with('updated', 'Social status has been changed');
    }
}
