<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroySuplierRequest;
use App\Http\Requests\StoreSuplierRequest;
use App\Http\Requests\UpdateSuplierRequest;
use App\Models\Suplier;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class SuplierController extends Controller
{
    use CsvImportTrait;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    public function index(Request $request)
    {
        abort_if(Gate::denies('suplier_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = Suplier::query()->where('branch_id',$this->branch_id)->select(sprintf('%s.*', (new Suplier())->table));
            $table = Datatables::of($query);
            $table->addIndexColumn();

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'suplier_show';
                $editGate = 'suplier_edit';
                $deleteGate = 'suplier_delete';
                $crudRoutePart = 'supliers';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });


            $table->editColumn('suplier', function ($row) {
                return $row->suplier ? $row->suplier : '';
            });
            $table->editColumn('mobile_no', function ($row) {
                return $row->mobile_no ? $row->mobile_no : '';
            });
            $table->editColumn('email', function ($row) {
                return $row->email ? $row->email : '';
            });
            $table->editColumn('type', function ($row) {
                return $row->type ? $row->type : '';
            });
            $table->editColumn('address', function ($row) {
                return $row->address ? $row->address : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.supliers.index');
    }

    public function create()
    {
        abort_if(Gate::denies('suplier_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.create');
    }

    public function store(StoreSuplierRequest $request)
    {
        $input = $request->all();
        $input['branch_id'] = $this->branch_id;
        $suplier = Suplier::create($input);

        toastr()->success('Supplier has been created!');
        return redirect()->route('admin.supliers.index');
    }

    public function edit(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.edit', compact('suplier'));
    }

    public function update(UpdateSuplierRequest $request, Suplier $suplier)
    {
        $input = $request->all();
        $input['branch_id'] = $this->branch_id;
        $suplier->update($input);

        toastr()->info('Supplier has been updated!');
        return redirect()->route('admin.supliers.index');
    }

    public function show(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.supliers.show', compact('suplier'));
    }

    public function destroy(Suplier $suplier)
    {
        abort_if(Gate::denies('suplier_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $suplier->forceDelete();

        toastr()->error('Supplier has been deleted!');
        return back();
    }

    public function massDestroy(MassDestroySuplierRequest $request)
    {
        Suplier::whereIn('id', request('ids'))->forceDelete();

        toastr()->error('Supplier has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
