<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreCashExpenseRequest;
use App\Http\Requests\UpdateCashExpenseRequest;
use App\Http\Resources\Admin\CashExpenseResource;
use App\Models\CashExpense;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class CashExpensesApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('cash_expense_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CashExpenseResource(CashExpense::with(['suplier'])->get());
    }

    public function store(StoreCashExpenseRequest $request)
    {
        $cashExpense = CashExpense::create($request->all());

        return (new CashExpenseResource($cashExpense))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(CashExpense $cashExpense)
    {
        abort_if(Gate::denies('cash_expense_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CashExpenseResource($cashExpense->load(['suplier']));
    }

    public function update(UpdateCashExpenseRequest $request, CashExpense $cashExpense)
    {
        $cashExpense->update($request->all());

        return (new CashExpenseResource($cashExpense))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(CashExpense $cashExpense)
    {
        abort_if(Gate::denies('cash_expense_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashExpense->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
