<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreCashPurchaseRequest;
use App\Http\Requests\UpdateCashPurchaseRequest;
use App\Http\Resources\Admin\CashPurchaseResource;
use App\Models\CashPurchase;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class CashPurchaseApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('cash_purchase_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CashPurchaseResource(CashPurchase::with(['suplier'])->get());
    }

    public function store(StoreCashPurchaseRequest $request)
    {
        $cashPurchase = CashPurchase::create($request->all());

        return (new CashPurchaseResource($cashPurchase))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(CashPurchase $cashPurchase)
    {
        abort_if(Gate::denies('cash_purchase_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CashPurchaseResource($cashPurchase->load(['suplier']));
    }

    public function update(UpdateCashPurchaseRequest $request, CashPurchase $cashPurchase)
    {
        $cashPurchase->update($request->all());

        return (new CashPurchaseResource($cashPurchase))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(CashPurchase $cashPurchase)
    {
        abort_if(Gate::denies('cash_purchase_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cashPurchase->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
