<?php

namespace App\Http\Controllers\Api\v1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreDepositOrSaleRequest;
use App\Http\Requests\UpdateDepositOrSaleRequest;
use App\Http\Resources\Admin\DepositOrSaleResource;
use App\Models\DepositOrSale;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class DepositOrSaleApiController extends Controller
{
     /**
     * Get
     * for All
     *  Details
     *
     * @return void
     */
    public function index()
    {
        abort_if(Gate::denies('deposit_or_sale_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new DepositOrSaleResource(DepositOrSale::where('deleted_at','=',null)->get());
    }

    /**
     * store for store
     * a new details
     *
     * @param  mixed $request
     * @return void
     */
    public function store(StoreDepositOrSaleRequest $request)
    {
        $depositOrSale = DepositOrSale::create($request->all());

        return (new DepositOrSaleResource($depositOrSale))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    /**
     * show
     * for particular
     * details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function show($id)
    {
        abort_if(Gate::denies('deposit_or_sale_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $depositOrSale = DepositOrSale::find($id);

        return new DepositOrSaleResource($depositOrSale);
    }

    /**
     * update
     * for update
     * particular details
     *
     * @param  mixed $request
     * @param  mixed $sheelCard
     * @return void
     */
    public function update(UpdateDepositOrSaleRequest $request, $id)
    {
        $depositOrSale = DepositOrSale::find($id);
        $depositOrSale->update($request->all());

        return (new DepositOrSaleResource($depositOrSale))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    /**
     * destroy
     * for delete
     * particular details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function destroy($id)
    {
        abort_if(Gate::denies('deposit_or_sale_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $depositOrSale = DepositOrSale::find($id);

        $depositOrSale->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
