<?php

namespace App\Http\Controllers\Api\v1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreFuelStockRequest;
use App\Http\Requests\UpdateDepositOrSaleRequest;
use App\Http\Resources\Admin\FuelStockResource;
use App\Models\FuelStock;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class FuelStockApiController extends Controller
{
     /**
     * Get
     * for All
     *  Details
     *
     * @return void
     */
    public function index()
    {
        abort_if(Gate::denies('fuel_stock_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new FuelStockResource(FuelStock::where('deleted_at','=',null)->get());
    }

    /**
     * store for store
     * a new details
     *
     * @param  mixed $request
     * @return void
     */
    public function store(StoreFuelStockRequest $request)
    {
        $fuelStock = FuelStock::create($request->all());

        return (new FuelStockResource($fuelStock))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    /**
     * show
     * for particular
     * details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function show(FuelStock $fuelStock)
    {
        abort_if(Gate::denies('fuel_stock_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new FuelStockResource($fuelStock);
    }

    /**
     * update
     * for update
     * particular details
     *
     * @param  mixed $request
     * @param  mixed $sheelCard
     * @return void
     */
    public function update(UpdateDepositOrSaleRequest $request, FuelStock $fuelStock)
    {
        $fuelStock->update($request->all());

        return (new FuelStockResource($fuelStock))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    /**
     * destroy
     * for delete
     * particular details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function destroy(FuelStock $fuelStock)
    {
        abort_if(Gate::denies('fuel_stock_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $fuelStock->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
