<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StorePumpRequest;
use App\Http\Requests\UpdatePumpRequest;
use App\Http\Resources\Admin\PumpResource;
use App\Models\Pump;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class PumpsApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('pump_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PumpResource(Pump::all());
    }

    public function store(StorePumpRequest $request)
    {
        $pump = Pump::create($request->all());

        return (new PumpResource($pump))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Pump $pump)
    {
        abort_if(Gate::denies('pump_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PumpResource($pump);
    }

    public function update(UpdatePumpRequest $request, Pump $pump)
    {
        $pump->update($request->all());

        return (new PumpResource($pump))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Pump $pump)
    {
        abort_if(Gate::denies('pump_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $pump->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
