<?php

namespace App\Models;

use \DateTimeInterface;
use App\Traits\Auditable;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class DrivewaySheet extends Model
{
    use SoftDeletes;
    use Auditable;
    use HasFactory;

    public const FUEL_TYPE_SELECT = [
        '95'  => 'U L P 95',
        '93'  => 'U L P 93',
        'D50' => 'DIESEL 50',
        'P'   => 'PARAFFIN',
    ];

    public $table = 'driveway_sheets';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    // protected $fillable = [
    //     'opening_balance',
    //     'closing_balance',
    //     'price',
    //     'fuel_type',
    //     'sales',
    //     'stock_value',
    //     'stock',
    //     'created_at',
    //     'updated_at',
    //     'deleted_at',
    // ];

    protected $guarded = [];

    public function getDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }
    
    public function setDateAttribute($value)
    {
        $this->attributes['date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function pump()
    {
        return $this->belongsTo(\App\Models\Pump::class);
    }

    public function fuel()
    {
        return $this->belongsTo(\App\Models\Fuel::class);
    }

    // protected function serializeDate(DateTimeInterface $date)
    // {
    //     return $date->format('Y-m-d H:i:s');
    // }
}
