@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col-6">
                    <h3 class="page-title">{{trans('cruds.bankStatment.title')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('cruds.bankStatment.title') }}</li>
                    </ul>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.bankStatment.title') }}
            </div>
            <div class="card-body">
                <form method="POST" action="{{ route('admin.bankstatement.import') }}" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="bank_account_id">Bank Account</label> 
                                <select name="bank_account_id" class="form-control {{$errors->has('bank_account_id') ? 'is-invalid' : ''}}" id="bank_account_id" required>
                                    @foreach ($bankAccount as $key => $value )
                                        <option value="{{$key}}">{{$value}}</option>
                                    @endforeach
                                </select>
                                @if($errors->first('bank_account_id'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('bank_account_id') }}
                                    </div>
                                @endif
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group {{ $errors->has('file') ? 'has-error' : '' }} input-file-block">
                                <label class="required" style="display: block;" for="file"> {{trans('cruds.bankStatment.fields.choose_file')}} </label>
                                <input type="file" name="file" id="file" class="prev-img input-file">
                                <!-- <label for="file" class="btn btn-info js-labelFile" data-toggle="tooltip" data-original-title="Preloader"> -->
                                    <!-- <i class="icon fa fa-upload"></i> -->
                                    <!-- <span class="js-fileName">{{trans('cruds.bankStatment.fields.choose_file')}}</span> -->
                                <!-- </label> -->
                            </div>
                        </div>
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button type="submit" class="btn btn-primary">{{trans('global.submit')}}</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
        <div class="card">
            <div class="row">
                <div class="col-lg-12">
                    <div class="card m-b-30">
                        <div class="card-header">
                            <h5 class="card-title mb-0">{{trans('cruds.bankStatment.title')}}</h5>
                        </div>
                        <div class="card-body">
                            <div class="row filter-row">
                              <div class="col-sm-3 col-md-3">
                                <div class="form-group form-focus">
                                  <div class="cal-icon">
                                    <input class="form-control floating date" name="min_date" type="text">
                                  </div>
                                  <label class="focus-label">From</label>
                                </div>
                              </div>
                              <div class="col-sm-3 col-md-3">
                                <div class="form-group form-focus">
                                  <div class="cal-icon">
                                    <input class="form-control floating date" name="max_date" type="text">
                                  </div>
                                  <label class="focus-label">To</label>
                                </div>
                              </div>
                              <div class="col-sm-2 col-md-2">
                                <a href="#" class="btn btn-success search-btn"> Search </a> 
                                <a class="btn btn-info" href="{{ route('admin.bank-statements.index') }}">Reset</a>
                              </div>
                            </div>
                            <div class="table-responsive">
                                <table class="table table-bordered table-hover datatable-statement">
                                    <thead>
                                        <tr>
                                            <th width="10"></th>
                                            <th>{{ trans('cruds.bankStatment.fields.id')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.date')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.amount')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.service_fee')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.cheque')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.balance')}}</th>
                                            <th>{{ trans('cruds.bankStatment.fields.description')}}</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
@parent
<script>
    $(function () {
        let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
        @can('account_delete')
        let deleteButtonTrans = '{{ trans('global.datatables.delete ') }}';
        let deleteButton = {
            text: deleteButtonTrans,
            url: "{{ route('admin.accounts.massDestroy') }}",
            className: 'btn-danger',
            action: function (e, dt, node, config) {
                var ids = $.map(dt.rows({
                    selected: true
                }).data(), function (entry) {
                    return entry.id
                });

                if (ids.length === 0) {
                    alert('{{ trans('global.datatables.zero_selected ') }}')

                    return
                }

                if (confirm('{{ trans('global.areYouSure ') }}')) {
                    $.ajax({
                            headers: {
                                'x-csrf-token': _token
                            },
                            method: 'POST',
                            url: config.url,
                            data: {
                                ids: ids,
                                _method: 'DELETE'
                            }
                        })
                        .done(function () {
                            location.reload()
                        })
                }
            }
        }
        dtButtons.push(deleteButton)
        @endcan

        let dtOverrideGlobals = {
            buttons: dtButtons,
            processing: true,
            serverSide: true,
            retrieve: true,
            aaSorting: [],
            ajax: {
              url: $(location).attr("href"),
                  data: function(d) {
                      d.min = $('input[name=min_date]').val();
                      d.max = $('input[name=max_date]').val();
                  }
              },
            columns: [{
                    data: 'placeholder',
                    name: 'placeholder'
                },
                {
                    data: 'id',
                    name: 'id'
                },
                {
                    data: 'date',
                    name: 'date'
                },
                {
                    data: 'amount',
                    name: 'amount'
                },
                {
                    data: 'service_fee',
                    name: 'service_fee'
                },
                {
                    data: 'cheque_number',
                    name: 'cheque_number'
                },
                {
                    data: 'balance',
                    name: 'balance'
                },
                {
                    data: 'description',
                    name: 'description'
                },
            ],
            orderCellsTop: true,
            order: [
                [1, 'desc']
            ],
            pageLength: 100,
        };
        let table = $('.datatable-statement').DataTable(dtOverrideGlobals);
        $('a[data-toggle="tab"]').on('shown.bs.tab click', function (e) {
            $($.fn.dataTable.tables(true)).DataTable()
                .columns.adjust();
        });

      // Event listener to the two range filtering inputs to redraw on input
      $('.search-btn').on("click", function(e) {
          e.preventDefault();
          $('input[name=min_date]').attr('required',true);
          $('input[name=max_date]').attr('required',true);
          if($('input[name=min_date]').val() != '' && $('input[name=max_date]').val() != ''){
              table.draw();
          }
          else{
              toastr.error('Min & Max date both are required.');
          }
      });
    });

</script>
@endsection

