@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.deposit.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.deposits.index')}}">{{trans('cruds.deposit.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ url('admin/deposits?date='.$deposit->date)  }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.deposit.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.deposits.update",[$deposit->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="deposit-edit-block">
                        <div class="row">
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="date">{{ trans('cruds.deposit.fields.date') }}</label>
                                    <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date"  value="{{ old('date', date('d/m/Y',strtotime($deposit->date))) }}" required>
                                    @if($errors->has('date'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('date') }}
                                        </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.deposit.fields.date_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="sub_category">{{ trans('cruds.deposit.fields.sub_category') }}</label>
                                    <select class="sub_cat form-control {{ $errors->has('sub_category') ? 'is-invalid' : '' }}" name="sub_category" required>
                                    @foreach ($subCategory as $key => $value)
                                        <option value="{{$key}}" {{$deposit->sub_category_id == $key ? 'selected':''}}>{{$value}}</option>
                                    @endforeach
                                    </select>
                                    @if($errors->has('sub_category'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('sub_category') }}
                                        </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.deposit.fields.sub_category_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="amount">{{ trans('cruds.deposit.fields.amount') }}</label>
                                    <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="number" min="1" step="any" name="amount"  value="{{ old('amount', $deposit->amount) }}" required>
                                    @if($errors->has('amount'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('amount') }}
                                        </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.deposit.fields.amount_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="bank_account">{{ trans('cruds.deposit.fields.bank_account') }}</label>
                                    <select class="form-control {{ $errors->has('bank_account') ? 'is-invalid' : '' }}" name="bank_account">
                                    @foreach ($bankAccount as $key => $value)
                                        <option value="{{$key}}" {{$deposit->bank_account_id == $key ? 'selected':''}}>{{$value}}</option>
                                    @endforeach
                                    </select>
                                    @if($errors->has('bank_account'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('bank_account') }}
                                        </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.deposit.fields.bank_account_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label for="detail">{{ trans('cruds.deposit.fields.detail') }}</label>
                                    <input class="form-control {{ $errors->has('detail') ? 'is-invalid' : '' }}" type="text" name="detail"  value="{{ old('detail', $deposit->detail) }}">
                                    @if($errors->has('detail'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('detail') }}
                                        </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.deposit.fields.detail_helper') }}</span>
                                </div>
                            </div>
                        </div>
                      <!--   <div class="row">
                            <div class="col-lg-4 pd-block {{$deposit->type == null ? 'd-none' : ''}}">
                                <div class="form-group">
                                    <label for="type">{{ trans('cruds.deposit.fields.pd') }}</label>
                                    <input type="checkbox" class="pd-check {{ $errors->has('type') ? 'is-invalid' : ''}}" name="type" value="{{$deposit->type != null ? '1' : null}}" {{$deposit->type != null ? 'checked' : ''}}>
                                    @if($errors->first('type'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('type') }}
                                        </div>
                                    @endif
                                </div>
                            </div>
                        </div> -->
                        <div class="row">
                            <div class="col-lg-4 deposit-block {{$deposit->deposit_date == null ? 'd-none' : ''}}">
                                <div class="form-group">
                                    <label for="tyep">{{ trans('cruds.deposit.fields.deposit_date') }}</label>
                                   <input type="text" name="deposit_date" class="deposit-input form-control date {{$errors->has('deposit_date') ? 'is-invalid':''}}" value="{{ $deposit->deposit_date != null ? date('d/m/Y',strtotime($deposit->deposit_date)) : null}}">
                                   @if ($errors->first('date'))
                                       <div class="invalid-feedback">
                                           {{$errors->first('deposit_date')}}
                                       </div>
                                   @endif
                               </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-lg-4 pay-block {{$deposit->ref_id == null ? 'd-none' : ''}}">
                                <div class="form-group">
                                    <label for="ref_id">{{ trans('cruds.deposit.fields.payment_against') }}</label>
                                    <select name="ref_id" class="pay-input form-control {{$errors->has('ref_id') ? 'is-invalid' : ''}}" id="ref_id">
                                        <option value="">Please Select</option>
                                        @if($currentpd != null)
                                        <option value="{{$currentpd->id}}" selected>{{$currentpd->detail}}</option>
                                        @endif
                                        @foreach ($pdpays as $key => $value )
                                            <option value="{{$key}}">{{$value}}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                {{-- <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button> --}}
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(document).ready(function(){
            $('body').on('change', '.sub_cat', function() {
                console.log($(this).val());
                $(this).closest('.deposit-edit-block').find('.deposit-input').val("");
                  $(this).closest('.deposit-edit-block').find('.pay-input').val("");
                  if($(this).val() == "51" || $(this).val() == "34" || $(this).val() == "35" || $(this).val() == "36"){
                    $(this).closest('.deposit-edit-block').find('.deposit-block').removeClass('d-none');
                    if($(this).val() == "51"){
                      $(this).closest('.deposit-edit-block').find('.deposit-input').prop('required',true);
                    }
                  }
                  else{                
                    $(this).closest('.deposit-edit-block').find('.deposit-block').addClass('d-none');
                    if($(this).val() == "51"){
                      $(this).closest('.deposit-edit-block').find('.deposit-input').prop('required',false);
                    }
                  }
                  if($(this).val() == "52"){
                    $(this).closest('.deposit-edit-block').find('.pay-block').removeClass('d-none');
                    $(this).closest('.deposit-edit-block').find('.pay-input').prop('required',true); }
                  else{                
                    $(this).closest('.deposit-edit-block').find('.pay-block').addClass('d-none');
                    $(this).closest('.deposit-edit-block').find('.pay-input').prop('required',false);
                  }
            });
        });
    </script>
@endsection

