@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.drivewaySheet.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('cruds.drivewaySheet.title_singular')}}</li>
                    </ul>
                </div>
                @can('driveway_sheet_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.driveway-sheets.create') }}" class="btn add-btn"><i class="fa fa-plus"></i> {{ trans('global.add') }} {{ trans('cruds.drivewaySheet.title_singular') }}</a>
                    </div>
                @endcan
            </div>
        </div>

        <div class="card">
            <div class="card-header">
                {{ trans('cruds.drivewaySheet.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
                <div class="table-responsive">
                    <table class=" table table-bordered table-hover datatable datatable-drivewaySheet">
                        <thead>
                            <tr>

                                <th>
                                    {{__('ID')}}
                                </th>
                                <th>
                                    {{ trans('cruds.drivewaySheet.fields.date') }}
                                </th>
                                <th>
                                {{ trans('global.status') }}
                                </th>
                                <th>
                                {{ trans('global.action') }}
                                </th>
                            </tr>
                        </thead>
                        <tbody>
                            @php
                                $i = 1;
                            @endphp
                            @foreach($drivewaysheet as $key => $data)
                                <tr>
                                    {{-- <td></td> --}}
                                    <td>
                                        {{$i}}
                                    </td>
                                    <td>
                                        {{ date('d-M-y', strtotime($data->date1)) ?? '' }}
                                    </td>
                                    <td>
                                        @if($data->is_approved == 1)
                                            <span class="badge bg-inverse-success">Approved</span>
                                        @else
                                            <span class="badge bg-inverse-danger">Not Approved</span>
                                        @endif
                                    </td>
                                    <td>
                                        @if($auth->is_admin == 1 && $data->is_approved == 0)
                                           <a class="btn btn-xs btn-success" onclick="approveSheet(`{{route('admin.driveway-sheets.approve', $data->date1)}}`)" title="Approve">
                                                <i class="la la-check"></i>
                                            </a>
                                        @endif
                                        @can('driveway_sheet_show')
                                            <a class="btn btn-xs btn-primary" href="{{ route('admin.driveway-sheets.view', $data->date1) }}" title="View">
                                                <i class="la la-eye"></i>
                                            </a>
                                        @endcan

                                        @if($data->is_approved == 0)
                                        @can('driveway_sheet_edit')
                                            <a class="btn btn-xs btn-info" href="{{ route('admin.driveway-sheets.datewise_edit', $data->date1) }}" title="Edit">
                                                <i class="la la-edit"></i>
                                            </a>
                                        @endcan

                                        @can('driveway_sheet_delete')
                                            <form action="{{ route('admin.driveway-sheets.delete', $data->date1) }}" method="POST"  title="Delete" onsubmit="return confirm('{{ trans('global.areYouSure') }}');" style="display: inline-block;">
                                                <input type="hidden" name="_method" value="DELETE">
                                                <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                                <button type="submit" class="btn btn-xs btn-danger"> <i class="la la-trash"></i> </button>
                                            </form>
                                        @endcan
                                        @endif
                                    </td>
                                    @php
                                        $i++;
                                    @endphp
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
<script>
    var redirecturl = url + "/admin/driveway-sheets";
    function approveSheet(link){
        $.confirm({
            title: "Approve DrivewaySheet",
            content: 'Are you sure to approve this item? You won\'t be able to edit or delete it',
            buttons: {
                OK: {
                    text: 'OK',
                    action: function() {
                        $.ajax({
                            url: link,
                            type: "GET",
                            dataType: "json",
                            success:function(data) {
                                toastr.success('Approved successfully');
                                setTimeout(function(){
                                     window.location = redirecturl;
                                }, 1000);
                            },
                            error: function(response){
                                toastr.error('Error in approving.');
                              $.each(response.responseJSON.errors, function (index, value) {
                                  toastr.error(value);
                              });
                            }
                        });
                    },
                },
                close: {
                    text: 'Cancel',
                },

            }
        });
    }
$(function () {
  $.extend(true, $.fn.dataTable.defaults, {select:false,columnDefs:false});

  let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
    @can('driveway_sheet_delete')
    let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
    let deleteButton = {
        text: deleteButtonTrans,
        url: "{{ route('admin.users.massDestroy') }}",
        className: 'bg-inverse-danger',
        action: function (e, dt, node, config) {
        var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
            return $(entry).data('entry-id')
        });

        if (ids.length === 0) {
            alert('{{ trans('global.datatables.zero_selected') }}')

            return
        }

        if (confirm('{{ trans('global.areYouSure') }}')) {
            $.ajax({
            headers: {'x-csrf-token': _token},
            method: 'POST',
            url: config.url,
            data: { ids: ids, _method: 'DELETE' }})
            .done(function () { location.reload() })
        }
        }
    }
    dtButtons.push(deleteButton)
    @endcan

  $.extend(true, $.fn.dataTable.defaults, {
    orderCellsTop: true,
    order: [[ 0, 'asc' ]],
    pageLength: 100,
  });
//   let table = $('.datatable-drivewaySheet:not(.ajaxTable)').DataTable({ buttons: dtButtons })
  let table = $('.datatable-drivewaySheet:not(.ajaxTable)').DataTable()
  $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
      $($.fn.dataTable.tables(true)).DataTable()
          .columns.adjust();
  });
  $('div#sidebar').on('transitionend', function(e) {
    $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
  })
  $(".buttons-select-all").hide();
  $(".buttons-select-none").hide();
})
</script>
@endsection
