@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.fuel.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.fuel-infos.index')}}">{{trans('cruds.fuelInfo.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.fuel-infos.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.fuelInfo.title') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.fuel-infos.update",[$fuelInfo->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row fuel_block">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="branch_id">{{ trans('cruds.fuelInfo.branch') }}</label>
                                <select class="form-control fetch_fuels select2 {{$errors->has('branch_id')? 'is-invalid' : ''}}" name="branch_id" id="branch_id" value="{{old('branch_id',$fuelInfo->name)}}" required?>
                                    <option value disabled {{ old('branch_id', $fuelInfo->branch_id) === null ? 'selected' : '' }}>
                                        {{ trans('global.pleaseSelect') }}</option>
                                    @foreach ($branches as $value)
                                    <option value="{{ $value->id }}" {{ old('branch_id', $fuelInfo->branch_id) == (string) $value->id ? 'selected' : '' }}>{{ $value->name }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('branch_id'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('branch_id') }}
                                </div>
                                @endif
                                {{-- <span class="help-block">{{ trans('cruds.fuelInfo.country_helper') }}</span> --}}
                            </div>
                        </div>

                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="fuel_id">{{ trans('cruds.fuelInfo.fuel_name') }}</label>
                                <select class="form-control fill_fuel select2 {{$errors->has('fuel_id')? 'is-invalid' : ''}}" name="fuel_id"
                                    id="fuel_id" value="{{old('fuel_id','')}}" required>
                                    <option value disabled {{ old('fuel_id', $fuelInfo->fuel_id) === null ? 'selected' : '' }}>
                                        {{ trans('global.pleaseSelect') }}</option>
                                    @foreach ($fuels as $key => $value)
                                    <option value="{{ $key }}" {{ old('fuel_id', $fuelInfo->fuel_id) == (string) $key ? 'selected' : '' }}>{{ $value }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('fuel_id'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('fuel_id') }}
                                </div>
                                @endif

                            </div>
                        </div>

                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="cost_price">  {{trans('cruds.fuelInfo.cost_price')}} </label>
                                <input class="form-control {{ $errors->has('cost_price') ? 'is-invalid' : '' }}" type="text" name="cost_price" id="cost_price" value="{{ old('cost_price', $fuelInfo->cost_price) }}" required>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="selling_price">  {{trans('cruds.fuelInfo.selling_price')}} </label>
                                <input class="form-control {{ $errors->has('selling_price') ? 'is-invalid' : '' }}" type="text" name="selling_price" id="selling_price" value="{{ old('selling_price', $fuelInfo->selling_price) }}" required>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="effective_from">  {{trans('cruds.fuelInfo.eff_from')}} </label>
                                <input class="form-control date {{ $errors->has('effect_from') ? 'is-invalid' : '' }}" type="text" name="effective_from" id="effective_from" value="{{ old('effective_from', date('d/m/Y',strtotime($fuelInfo->effective_from))) }}" required>
                            </div>
                        </div>
                        <div class="col-lg-2 custom-switch">
                            <div class="form-group">
                                <br>
                                <label class="custom-switch">
                                    <input id="status" type="checkbox" {{$fuelInfo->status ? 'checked' : 0 }}  value="1" name="status" class="custom-control-input">
                                    <label class="custom-control-label" for="status"> Status</label>
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">

                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
