@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.machine.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        @if (isset($machine))
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.machines.index')}}">{{trans('cruds.machine.title')}}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                        @else
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('cruds.machine.title')}}</li>
                        @endif
                    </ul>
                </div>
                @if(isset($machine))
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.machines.index') }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
                @else
                {{-- <div class="col-auto float-right ml-auto">
                        <a href="" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add')}}
                {{trans('cruds.machine.title_singular')}}</a>
            </div> --}}
            @endif
        </div>
    </div>
    @can('machine_create','machine_edit')
        <div class="card">
            <div class="card-header">
                @if (isset($machine))
                {{ trans('global.edit') }} {{ trans('cruds.machine.title_singular') }}
                @else
                {{ trans('global.add') }} {{ trans('cruds.machine.title_singular') }}
                @endif
                {{-- <span style="float: right;">
                            <a href="#" class="text-danger"><i class="fa fa-close"></i></a>
                        </span> --}}
            </div>
            <div class="card-body">
                @if (isset($machine))
                <form action="{{route('admin.machines.update',[$machine->id])}}" method="POST" enctype="multipart/form-data">
                    @method('PUT')
                    @else
                    <form action="{{route('admin.machines.store')}}" method="post" enctype="multipart/form-data">
                        @endif
                        <div class="row">
                            @csrf
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label for="station">{{ trans('cruds.header.fields.type')}}</label>
                                    <select class="form-control {{$errors->has('type') ? 'is-invalid' : ''}}" name="type" id="type" required>
                                        <option value="">Please Select</option>
                                        <option value="fnb" {{isset($machine) && $machine->type == 'fnb' ? 'selected': ''}} >FNB</option>
                                        <option value="stanbic" {{isset($machine) && $machine->type == 'stanbic' ? 'selected': ''}} >Stanbic</option>
                                        <option value="barclays" {{isset($machine) && $machine->type == 'barclays' ? 'selected': ''}} >Barclays</option>
                                    </select>
                                    @if($errors->first('type'))
                                        <div class="invalid-feedback">
                                            {{ $errors->first('type') }}
                                        </div>
                                    @endif
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="title">{{ trans('cruds.machine.fields.title') }}</label>
                                    <input class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" type="text"
                                        name="title" id="title"
                                        value="{{ old('title', isset($machine)?$machine->title: '') }}" required>
                                    @if($errors->has('title'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('title') }}
                                    </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.machine.fields.title_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label for="remarks">{{ trans('cruds.machine.fields.remarks') }}</label>
                                    <input class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}"
                                        type="text" name="remarks" id="remarks"
                                        value="{{ old('remarks', isset($machine)?$machine->remarks:'') }}">
                                    @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.machine.fields.remarks_helper') }}</span>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-lg-12">
                                @if (isset($machine))
                                <button class="btn btn-primary" type="submit">{{ trans('global.update') }}</button>
                                @else
                                <button class="btn btn-info" type="reset">{{ trans('global.reset') }}</button>
                                <button class="btn btn-primary" type="submit">{{ trans('global.add') }}</button>
                                @endif
                            </div>
                        </div>
                    </form>
            </div>
        </div>
    @endcan

    <div class="card">
        <div class="card-header">
            {{ trans('global.list') }} {{ trans('cruds.machine.title_singular') }}
        </div>
        <div class="card-body">
            <table class="table table-bordered datatable datatable-machine">
                <thead>
                    <tr>
                        <th style="width: 10px;"></th>
                        <th>
                            {{__('ID')}}
                        </th>
                        <th>
                            {{ trans('cruds.header.fields.type') }}
                        </th>
                        <th>
                            {{ trans('cruds.machine.fields.title') }}
                        </th>
                        <th>
                            {{ trans('cruds.machine.fields.remarks') }}
                        </th>
                        <th></th>
                    </tr>
                </thead>
                @if (count($machine_list) == 0)

                @else
                @php
                    $i = 1;
                @endphp
                <tbody>
                    @foreach ($machine_list as $ml)
                        <tr data-entry-id="{{$ml->id}}">
                            <td></td>
                            <td>
                                {{$i}}
                            </td>
                            <td>
                                {{ucfirst($ml->type)}}
                            </td>
                            <td>
                                {{$ml->title}}
                            </td>
                            <td>
                                {{$ml->remarks}}
                            </td>
                            <td>
                                <div class="button-list">
                                    @can('machine_edit')
                                        <a href="{{route('admin.machines.edit', $ml->id)}}" class="btn btn-xs btn-info"><i
                                            class="la la-edit"></i></a>
                                    @endcan
                                    @can('machine_delete')
                                        <button type="button" class="btn btn-xs btn-danger" data-toggle="modal"
                                            data-target="#deleteModal{{$ml->id}}"><i class="la la-trash"></i></button>
                                    @endcan
                                    <!-- Modal -->
                                    <div id="deleteModal{{$ml->id}}" class="delete-modal modal fade" role="dialog">
                                        <div class="modal-dialog modal-sm">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <button type="button" class="close" data-dismiss="modal">&times;</button>
                                                    <div class="delete-icon"></div>
                                                </div>
                                                <div class="modal-body text-center">
                                                    <h4 class="modal-heading">Are You Sure ?</h4>
                                                    <p>Do you really want to delete these records?<br> This process cannot be
                                                        undone.</p>
                                                </div>
                                                <div class="modal-footer">
                                                    {!! Form::open(['method' => 'DELETE', 'route' => ['admin.machines.destroy',$ml->id]]) !!}
                                                    <button type="reset" class="btn btn-dark" data-dismiss="modal">No</button>
                                                    <button type="submit" class="btn btn-danger">Yes</button>
                                                    {!! Form::close() !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                            @php
                                $i++;
                            @endphp
                        </tr>
                    @endforeach
                </tbody>
                @endif
            </table>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(function () {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('machine_delete')
                let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
                let deleteButton = {
                    text: deleteButtonTrans,
                    url: "{{ route('admin.machines.massDestroy') }}",
                    className: 'bg-inverse-danger',
                    action: function (e, dt, node, config) {
                    var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                        return $(entry).data('entry-id')
                    });

                    if (ids.length === 0) {
                        alert('{{ trans('global.datatables.zero_selected') }}')

                        return
                    }

                    if (confirm('{{ trans('global.areYouSure') }}')) {
                        $.ajax({
                        headers: {'x-csrf-token': _token},
                        method: 'POST',
                        url: config.url,
                        data: { ids: ids, _method: 'DELETE' }})
                        .done(function () { location.reload() })
                    }
                    }
                }
                dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [[ 1, 'asc' ]],
                pageLength: 100,
            });
            let table = $('.datatable-machine:not(.ajaxTable)').DataTable({ buttons: dtButtons })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });
            $('div#sidebar').on('transitionend', function(e) {
                $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
            })

        })
    </script>
@endsection
