@extends('layouts.admin')
@section('content')
​<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{ trans('cruds.drivewayReport.title_singular') }} {{ trans('global.list') }}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item active">{{ trans('cruds.drivewayReport.title_singular') }} {{ trans('global.list') }}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.driveway-sheets.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.drivewayReport.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body table-responsive">
                <div class="row m-b-20">
                    <div class="col-lg-6">
                        <form method="GET" action="{{route('admin.reports.driveway')}}">
                            <label for="search-date">Choose Date</label>
                            <div class="input-group">
                                <input type="text" placeholder="Start Date" name="date" id="fromDate" value="{{date('d/m/Y',strtotime($date))}}" class="form-control floating datetimepicker">
                                <div class="input-group-append">
                                    <button class="btn btn-outline-info" type="submit">Search</button>
                                    <a class="btn btn-outline-secondary" href="{{ route('admin.reports.driveway') }}">Reset</a>
                                </div>
                            </div>
                         </form>
                    </div>
                    <div class="col-lg-6 text-right">
                        <a href="{{route('admin.export.driveway',date('Y-d-m',strtotime(request('date'))))}}" class="btn btn-outline-success">Export Excel</a>
                    </div>
                </div>
                <table class="table table-bordered table-striped table-hover report-table">
                    @php
                        $sum = [];
                        $mechanical = [];
                        $drivesale = $drivesheet->sum('stock_value');
                        $depositdata = [];
                        $amount_sale_deposit = $deposit->whereNotIn('sub_category_id',['50','51','52'])->sum('amount');
                        $amount_deposit = $deposit->sum('amount');
                    @endphp
                    <thead>
                        <tr>
                            <th>{{ trans('cruds.pump.fields.pump') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.opening') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.closing') }}</th>
                             @foreach($fuels as $key => $fuel)
                                <th>{{ $fuel }}</th>
                            @endforeach
                            <th>{{ trans('global.total') }}</th>
                            <th>{{ trans('cruds.report.fuelSale') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($drivesheet as $key => $data)
                            <tr>
                                <td>{{$data->pump->pump}}</td>
                                <td>{{number_format($data->opening_balance,2)}}</td>
                                <td>{{number_format($data->closing_balance,2)}}</td>
                                @foreach($fuels as $id => $fuel)
                                    <td>
                                        @if($data->fuel_id == $id)
                                            {{number_format($data->stock,2)}}
                                        @endif
                                    </td>
                                @endforeach
                                <td></td>
                                <td>{{number_format($data->stock_value,2)}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.computerSale') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $sale[$id] = count($fuelstock) > 0 && !empty($fuelstock->where('fuel_type',$id)->first()) ? $fuelstock->where('fuel_type',$id)->first()->sale : 0;
                                @endphp
                                <td><b>{{number_format($sale[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sale),2)}}</b></td>
                            <td><b>{{number_format($drivesale,2)}}</b></td>
                        </tr>
                        <tr>
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.mechanicalSale') }} {{ trans('cruds.report.inLtr') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $sum[$id] = $drivesheet->where('fuel_id',$id)->sum('stock');
                                @endphp
                                <td><b>{{number_format($sum[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sum),2)}}</b></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.mechanicalValue') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $selling_price = $fuelprices->where('fuel_id',$id)->first();
                                    $price = $selling_price ? $selling_price->selling_price : '0';
                                    $mechanical[$id] = $sum[$id] * (float) $price;
                                @endphp
                                <td><b>{{number_format($mechanical[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($mechanical),2)}}</b></td>
                            <td></td>
                        </tr>
                        <tr class="highlight">
                            <td colspan="3" class="left"><strong>{{ trans('cruds.report.difference') }} {{ trans('cruds.report.inLtr') }}</strong></td>
                            @foreach($fuels as $id => $fuel)
                                @php
                                    $diff[$id] = $sum[$id] - $sale[$id];
                                @endphp
                                <td><b>{{number_format($diff[$id],2)}}</b></td>
                            @endforeach
                            <td><b>{{number_format(array_sum($sum) - array_sum($sale),2)}}</b></td>
                            <td></td>
                        </tr>
                    </tfoot>
                </table>
                <!-- <h5 class="m-t-20 m-b-20"><u>{{ trans('cruds.fuelStock.title_singular') }} {{ trans('cruds.fuelStock.fields.control') }}</u></h5> -->
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.fuelStock.title_singular') }} {{ trans('cruds.fuelStock.fields.control') }}
            </div>

            <div class="card-body table-responsive">
                <table class="table table-bordered table-striped table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">Fuel</th>
                            <th>{{ trans('cruds.fuelStock.fields.opening_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.purchase') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.calculated_stock') }}</th>
                            <th>{{ trans('cruds.report.lessSale') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_dips') }}</th>
                            <th>{{ trans('cruds.report.difference') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $opening_stock = 0;
                            $purchase = 0;
                            $cal_stock = 0;
                            $less_sale = 0;
                            $closing_dips = 0;
                            $closing_stock = 0;
                        @endphp
                        @foreach($fuelstock as $key => $data)
                            @php
                                $l_sale = $drivesheet->where('fuel_id',$data->fuel_type)->sum('stock');
                                $clos_stock = $data->stock - $l_sale;
                                $opening_stock += $data->opening_stock;
                                $purchase += $data->purchase;
                                $cal_stock += $data->stock;
                                $less_sale += $l_sale;
                                $closing_dips += $data->closing_dips;
                                $closing_stock += $clos_stock;
                            @endphp
                            <tr>
                                <td class="left"><b>{{$data->fuel->fuel_name}}</b></td>
                                <td>{{number_format($data->opening_stock,2)}}</td>
                                <td>{{number_format($data->purchase,2)}}</td>
                                <td>{{number_format($data->stock,2)}}</td>
                                <td>{{number_format($l_sale,2)}}</td>
                                <td>{{number_format($clos_stock,2)}}</td>
                                <td>{{number_format($data->closing_dips,2)}}</td>
                                <td>{{number_format($data->closing_dips - $clos_stock,2)}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    @if(count($drivesheet) > 0 && count($fuelstock) > 0)
                    <tfoot>
                        <tr class="highlight">
                            <td class="left"><strong>Total</strong></td>
                            <td><b>{{number_format($opening_stock,2)}}</b></td>
                            <td><b>{{number_format($purchase,2)}}</b></td>
                            <td><b>{{number_format($cal_stock,2)}}</b></td>
                            <td><b>{{number_format($less_sale,2)}}</b></td>
                            <td><b>{{number_format($closing_stock,2)}}</b></td>
                            <td><b>{{number_format($closing_dips,2)}}</b></td>
                            <td><b>{{number_format($closing_dips - $closing_stock,2)}}</b></td>
                        </tr>
                    </tfoot>
                    @endif
                </table>
                <!-- <h5 class="m-t-20 m-b-20"><u>{{ trans('cruds.report.saleReport') }}</u></h5> -->
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.report.saleReport') }}
            </div>

            <div class="card-body table-responsive">
                @php
                    $cashier_shop_sale = $cashiersale->where('financialcategory.code','sub23')->sum('amount');
                    $cashier_fuel_sale = $cashiersale->where('financialcategory.code','sub22')->sum('amount');
                    $fuel_total = $drivesale + ($fuelsale != null ? $fuelsale->sum('amount') : 0);
                    $sale_total = $shopsale != null ? $shopsale->sum('amount') : 0;
                @endphp
                <table class="table table-bordered table-striped table-hover report-table">
                    <thead>
                        <tr>
                            <th></th>
                            <th>{{ trans('cruds.report.computer_sale') }}</th>
                            <th>{{ trans('cruds.report.total_sale') }}</th>
                            <th>{{ trans('cruds.report.variance') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                            <tr>
                                <th class="left">{{ trans('cruds.report.fuel_sale') }}</th>
                                <td><a href="#" data-toggle="modal" data-target="#cashierfuelModal">{{ number_format($cashier_fuel_sale,2)}}</a></td>
                                <td><a href="#" data-toggle="modal" data-target="#fuelModal">{{ number_format($fuel_total,2) }}</a></td>
                                <td>{{ number_format($fuel_total - $cashier_fuel_sale,2)}}</td>
                            </tr>
                            <tr>
                                <th class="left">{{ trans('cruds.report.shop_sale') }}</th>
                                <td><a href="#" data-toggle="modal" data-target="#cashiershopModal">{{ number_format($cashier_shop_sale,2)}}</a></td>
                                <td><a href="#" data-toggle="modal" data-target="#saleModal">{{ number_format($sale_total,2)}}</a></td>
                                <td>{{ number_format($sale_total - $cashier_shop_sale,2)}}</td>
                            </tr>
                            <tr>
                                <th class="left">{{ trans('cruds.report.total') }}</th>
                                <td>{{ number_format($cashier_shop_sale + $cashier_fuel_sale,2)}}</td>
                                <td>{{  number_format($fuel_total + $sale_total,2)}}</td>
                                <td></td>
                            </tr>
                    </tbody>
                </table>
                <!-- <h5 class="m-t-20 m-b-20"><u>{{ trans('cruds.report.totalReport') }}</u></h5> -->
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.report.depositReport') }}
            </div>

            <div class="card-body table-responsive">
                <table class="table table-bordered table-striped table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.category') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($category as $cat)
                        @php
                            $depositdata[$cat->id] = $deposit->where('financialCategory.header_id',$cat->id)->sum('amount');
                        @endphp
                            <tr>
                                <th class="left">{{ $cat->header_name }}</th>
                                <td><a href="#" data-toggle="modal" data-target="#deposit{{$cat->id}}Modal">{{ number_format($depositdata[$cat->id],2)}}</a></td>
                            </tr>
                        @endforeach
                        <tfoot>
                            <tr class="highlight">
                                <td class="left">{{ trans('cruds.report.total') }}</td>
                                <td>{{ number_format($amount_deposit,2)}}</td>
                            </tr>
                        </tfoot>
                    </tbody>
                </table>
                <!-- <h5 class="m-t-20 m-b-20"><u>{{ trans('cruds.report.totalReport') }}</u></h5> -->
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.report.totalReport') }}
            </div>

            <div class="card-body table-responsive">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.maintitle') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $shell_total = !empty($shell) ? $shell->total_amount : '0';
                            $driveway_acc_total = !empty($driveway_account) ? $driveway_account->total_amount : '0';
                            $total_sale = $sale_total + $fuel_total;
                            $pd_pay = $deposit->where('sub_category_id','52')->sum('amount');
                            $cash_sale = $total_sale - $speed->sum('total_amount') - $shell_total - $driveway_acc_total + $pd_pay;
                            $total_variance = $amount_sale_deposit - $cash_sale;
                        @endphp
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.fuelSale') }}</td>
                            <td>{{ $drivesale}}</td>
                        </tr>
                        @if($fuelsale != null)
                        @foreach($fuelsale as $item)
                            <tr>
                                <td class="left">{{ ucfirst($item->financialCategory->title)}}</td>
                                <td>{{ $item->amount}}</td>
                            </tr>
                        @endforeach
                        @endif
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.fuelTotal') }}</td>
                            <td>{{ $fuel_total}}</td>
                        </tr>
                        @if($shopsale != null)
                        @foreach($shopsale as $item)
                        <tr>
                            <td class="left">{{ ucfirst($item->financialCategory->title)}}</td>
                            <td>{{ $item->amount}}</td>
                        </tr>
                        @endforeach
                        @endif
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.total_sale') }}</td>
                            <td>{{ $total_sale}}</td>
                        </tr>
                        @if($speed != null)
                        @foreach($speed as $item)
                        <tr>
                            <td class="left">{{ ucfirst($item->type)}}</td>
                            <td>{{ $item->total_amount}}</td>
                        </tr>
                        @endforeach
                        @endif
                        <tr>
                            <td class="left">{{ trans('cruds.report.sheelCard') }}</td>
                            <td>{{ $shell_total}}</td>
                        </tr>
                        <tr>
                            <td class="left">{{ trans('cruds.report.accountSale') }}</td>
                            <td>{{ $driveway_acc_total}}</td>
                        </tr>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.cashSale') }}</td>
                            <td>{{ $cash_sale}}</td>
                        </tr>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.amountDeposit') }}</td>
                            <td>{{ $amount_deposit}}</td>
                        </tr>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.variance') }}</td>
                            <td>{{ $total_variance}}</td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        <div class="modal fade" id="cashiershopModal" tabindex="-1" role="dialog" aria-labelledby="saleModalLabel" aria-hidden="true">
          <div class="modal-dialog">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title" id="saleModalLabel">{{ trans('cruds.report.cashier_shop_sale') }}</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              </div>
              <div class="modal-body">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.cashier') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($cashiersale->where('financialcategory.code','sub23') as $item)
                            <tr>
                                <td class="left">{{ ucfirst($item->cashier->name)}}</td>
                                <td>{{ $item->amount}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.total') }}</td>
                            <td>{{ $cashier_shop_sale}}</td>
                        </tr>
                    </tfoot>
                </table>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
              </div>
            </div>
          </div>
        </div>
        <div class="modal fade" id="cashierfuelModal" tabindex="-1" role="dialog" aria-labelledby="fuelModalLabel" aria-hidden="true">
          <div class="modal-dialog">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title" id="fuelModalLabel">{{ trans('cruds.report.cashier_fuel_sale') }}</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              </div>
              <div class="modal-body">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.cashier') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($cashiersale->where('financialcategory.code','sub22') as $item)
                            <tr>
                                <td class="left">{{ ucfirst($item->cashier->name)}}</td>
                                <td>{{ $item->amount}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.total') }}</td>
                            <td>{{ $cashier_fuel_sale}}</td>
                        </tr>
                    </tfoot>
                </table>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
              </div>
            </div>
          </div>
        </div>
        <div class="modal fade" id="saleModal" tabindex="-1" role="dialog" aria-labelledby="saleModalLabel" aria-hidden="true">
          <div class="modal-dialog">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title" id="saleModalLabel">{{ trans('cruds.report.sale') }}</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              </div>
              <div class="modal-body">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.category') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @if($shopsale != null)
                        @foreach($shopsale as $item)
                            <tr>
                                <td class="left">{{ ucfirst($item->financialCategory->title)}}</td>
                                <td>{{ $item->amount}}</td>
                            </tr>
                        @endforeach
                        @endif
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.total') }}</td>
                            <td>{{ $sale_total}}</td>
                        </tr>
                    </tfoot>
                </table>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
              </div>
            </div>
          </div>
        </div>
        <div class="modal fade" id="fuelModal" tabindex="-1" role="dialog" aria-labelledby="fuelModalLabel" aria-hidden="true">
          <div class="modal-dialog modal-lg">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title" id="fuelModalLabel">{{ trans('cruds.report.driveway_fuel_sale') }}</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              </div>
              <div class="modal-body">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th>{{ trans('cruds.pump.fields.pump') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.opening') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.closing') }}</th>
                             @foreach($fuels as $key => $fuel)
                                <th>{{ $fuel }}</th>
                            @endforeach
                            <th>{{ trans('cruds.report.fuelSale') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($drivesheet as $key => $data)
                            <tr>
                                <td>{{$data->pump->pump}}</td>
                                <td>{{$data->opening_balance}}</td>
                                <td>{{$data->closing_balance}}</td>
                                @foreach($fuels as $id => $fuel)
                                    <td>
                                        @if($data->fuel_id == $id)
                                            {{$data->stock}}
                                        @endif
                                    </td>
                                @endforeach
                                <td>{{$data->stock_value}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td colspan="3">{{ trans('cruds.report.fuelSale') }}</td>
                            @foreach($fuels as $id => $fuel)
                                <td></td>
                            @endforeach
                            <td>{{ $drivesale}}</td>
                        </tr>
                        @if($fuelsale != null && count($fuelsale) > 0)
                        @foreach($fuelsale as $item)
                            <tr>
                                <td colspan="3">{{ ucfirst($item->financialCategory->title)}}</td>
                                @foreach($fuels as $id => $fuel)
                                    <td></td>
                                @endforeach
                                <td>{{ $item->amount}}</td>
                            </tr>
                        @endforeach
                        @endif
                        <tr class="highlight">
                            <td colspan="3">{{ trans('cruds.report.fuelTotal') }}</td>
                            @foreach($fuels as $id => $fuel)
                                <td></td>
                            @endforeach
                            <td>{{ $fuel_total}}</td>
                        </tr>
                    </tfoot>
                </table>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
              </div>
            </div>
          </div>
        </div>
        @foreach($category as $cat)
        <div class="modal fade" id="deposit{{$cat->id}}Modal" tabindex="-1" role="dialog" aria-labelledby="depositModalLabel" aria-hidden="true">
          <div class="modal-dialog">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title" id="depositModalLabel">{{$cat->header_name}}</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              </div>
              <div class="modal-body">
                <table class="table table-bordered table-hover report-table">
                    <thead>
                        <tr>
                            <th class="left">{{ trans('cruds.report.category') }}</th>
                            <th>{{ trans('cruds.report.amount') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($cat->subcategories as $item)
                            @php
                                $deposit_sub_total = $deposit->where('sub_category_id',$item->id)->sum('amount');
                            @endphp
                            <tr>
                                <td class="left">{{ ucfirst($item->title)}}</td>
                                <td>{{ number_format($deposit_sub_total,2)}}</td>
                            </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr class="highlight">
                            <td class="left">{{ trans('cruds.report.total') }}</td>
                            <td>{{ number_format($depositdata[$cat->id],2)}}</td>
                        </tr>
                    </tfoot>
                </table>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
              </div>
            </div>
          </div>
        </div>
        @endforeach
    </div>
</div>

@endsection
@section('scripts')
@parent
<script>
     $(function () {
        let table = $('.datatable-driveway').DataTable({
            "ordering": false
        });
        $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
            $($.fn.dataTable.tables(true)).DataTable()
                .columns.adjust();
        });
    });
</script>

@endsection
