@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.speedPoint.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.speed-points.index')}}">{{trans('cruds.speedPoint.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.speed-points.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.speedPoint.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route('admin.speed-points.update') }}" id="speed_point_form" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="reconcilation_type">{{ trans('cruds.speedPoint.fields.reconcilation_type')}}</label>
                                <select class="form-control {{$errors->has('reconcilation_type') ? 'is-invalid' : ''}}" name="reconcilation_type" id="reconcilation_type" required>
                                    @foreach ($machines as $key => $value )
                                        <option value="{{$key}}" {{ !empty($machine) && $machine == $key ? 'selected' : ''}}>{{$value}}</option>
                                    @endforeach
                                </select>
                                @if($errors->first('reconcilation_type'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('reconcilation_type') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.speedPoint.fields.reconcilation_type_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="date">{{ trans('cruds.speedPoint.fields.date') }}</label>
                                <input type="text" name="date" id="date" class="form-control floating datetimepicker {{$errors->has('date') ? 'is-invalid': ''}}" value="{{ isset($date) ?  date('d/m/Y',strtotime($date)) : ''}}" required>
                                @if($errors->first('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.speedPoint.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="batch_no">{{ trans('cruds.speedPoint.fields.batch_no') }}</label>
                                <input type="number" step="1" name="batch_no" id="batch_no" class="form-control {{$errors->has('batch_no') ? 'is-invalid': ''}}" value="{{isset($batch) ?  $batch : ''}}" required>
                                @if($errors->first('batch_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('batch_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.speedPoint.fields.batch_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="bank_account">{{ trans('cruds.speedPoint.fields.bank_account') }}</label>
                                <select name="bank_account" class="form-control {{$errors->has('bank_account') ? 'is-invalid' : ''}}" id="bank_account" required="">
                                    @foreach ($bankAccount as $key => $value )
                                        <option value="{{$key}}" {{ !empty($speedpoint->first()) && $speedpoint->first()->bank_account_id == $key ? 'selected' : ''}}>{{$value}}</option>
                                    @endforeach
                                </select>
                                @if($errors->first('bank_account'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('bank_account') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.speedPoint.fields.bank_account_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <table class="table table-bordered" id="field_container">
                                <tr>
                                    <th>
                                        {{ trans('cruds.speedPoint.fields.shift_no') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.speedPoint.fields.seq_no') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.speedPoint.fields.amount') }}
                                    </th>
                                    <th></th>
                                </tr>
                                @foreach($speedpoint as $key => $speed)
                                    <tr id="copy_content">
                                        <td>
                                            <input type="hidden" name="speed_id[{{$key}}]" value="{{$speed->id}}">
                                            <div class="form-group small">
                                                <select name="shift[{{$key}}]" class="form-control {{$errors->has('shift.*') ? 'is-invalid' : ''}}" id="shift[{{$key}}]">
                                                    @foreach ($shift as $item => $value )
                                                        <option value="{{$item}}" {{$speed->shift_no == $item ? 'selected' : ''}}>{{$value}}</option>
                                                    @endforeach
                                                </select>
                                                @if($errors->first('shift.*'))
                                                    <div class="invalid-feedback">
                                                        {{ $errors->first('shift.*') }}
                                                    </div>
                                                @endif
                                            </div>
                                        </td>
                                        <td>
                                            <div class="form-group small">
                                                <input type="text" class="form-control {{ $errors->has('seq_no.*') ? 'is-invalid' : ''}}" id="seq_no[{{$key}}]" name="seq_no[{{$key}}]" value="{{$speed->seq_no}}">
                                                @if($errors->first('seq_no.*'))
                                                    <div class="invalid-feedback">
                                                        {{ $errors->first('seq_no.*') }}
                                                    </div>
                                                @endif
                                                <span class="help-block">{{ trans('cruds.speedPoint.fields.seq_no_helper') }}</span>
                                            </div>
                                        </td>
                                        <td>
                                            <div class="form-group small">
                                                <input type="number" min="0" step="any" class="form-control {{ $errors->has('amount.*') ? 'is-invalid' : ''}}" id="amount[{{$key}}]" name="amount[{{$key}}]" value="{{$speed->amount}}">
                                                @if($errors->first('amount.*'))
                                                    <div class="invalid-feedback">
                                                        {{ $errors->first('amount.*') }}
                                                    </div>
                                                @endif
                                                <span class="help-block">{{ trans('cruds.speedPoint.fields.amount_helper') }}</span>
                                            </div>
                                        </td>                                        
                                        <td>
                                            @if($key != 0)
                                            <a href="#" data-id="{{$speed->id}}" class="btn btn-xs btn-danger remove_ele"> <i class="la la-trash"></i> </a>
                                            @endif
                                        </td>

                                    </tr>
                                @endforeach
                                <tr class="clone_ele d-none">
                                    <td>
                                        <div class="form-group small">
                                            <select name="shift_new[0]" class="form-control {{$errors->has('shift_new.*') ? 'is-invalid' : ''}}" id="shift_new[0]">
                                                @foreach ($shift as $key => $value )
                                                    <option value="{{$key}}">{{$value}}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('seq_no_new.*') ? 'is-invalid' : ''}}" id="seq_no_new[0]" name="seq_no_new[0]" value="">
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" min="0" step="any" class="form-control {{ $errors->has('amount_new.*') ? 'is-invalid' : ''}}" id="amount_new[0]" name="amount_new[0]" value="">
                                        </div>
                                    </td>
                                    <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                                </tr>
                            </table>
                            <div class="row my-3">
                                <div class="col-lg-12 text-center">
                                    <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button class="btn btn-info" type="reset">
                                            {{ trans('global.reset') }}
                                        </button>
                                        <button class="btn btn-primary" id="btn_submit" type="submit">
                                            {{ trans('global.save') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection

@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                    x++;
                    var clone_ele = $('.clone_ele:last').clone();
                    clone_ele.removeClass('d-none');
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.removeAttribute("disabled");
                        this.value = '';
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });


            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });

            //  For delete the existing record
            $('#field_container').on('click','.remove_ele', function (ele) {
                var id = $(this).attr('data-id');
                var cus_url = "{{route('admin.speed-points.destroy', '')}}"+"/"+id;
                var _token = '{{csrf_token()}}';

                if (confirm('{{ trans('global.areYouSure') }}')) {
                    $.ajax({
                        headers: {'x-csrf-token': _token},
                        method: 'POST',
                        url: cus_url,
                        data: { id: id, _method: 'DELETE' },
                        success: function (response) {
                            toastr.error(response.message);
                        }
                    });
                    $(this).closest('tr').remove();
                }
            });

            var i = 0;
            $('#speed_point_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        toastr.success(response.message);
                        document.getElementById('speed_point_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                        $.each(response.responseJSON.errors, function (index, value) {
                            toastr.error(value);
                            $("#btn_submit").prop('disabled', false);
                        });
                    }
               });
            });
        });
    </script>
@endsection
